import org.junit.jupiter.api.Test;

import java.util.Arrays;

import static org.junit.jupiter.api.Assertions.assertEquals;

class GameOutcomeSolverTest {
    @Test
    void calculateOutcome001() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "|*| | |",
                        "|#|#|*|",
                        "|*|#|*|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome002() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome003() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| | | | | | |",
                        "| |#|#| | |*|*| |#|#|*|*| | | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome004() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | |",
                        "| | | |*| |",
                        "| | | |*| |",
                        "| | | |#| |",
                        "|*|#|#|#| |",
                        "|*|*|#|#| |",
                        "|*|*|#|*|#|",
                        "|*|*|#|#|*|",
                        "|*|*|#|#|#|",
                        "|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome005() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*| | | | |",
                        "|*| | | | |",
                        "|*| | | | |",
                        "|#|#|#| | |",
                        "|*|*|*| | |",
                        "|*|#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome006() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| | |*|",
                        "|*| |#|*|",
                        "|*| |#|#|",
                        "|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome007() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|#|*|",
                        "|#|*|*|*|",
                        "|*|#|*|*|",
                        "|#|*|*|#|",
                        "|*|#|#|#|",
                        "|#|#|*|#|",
                        "|*|#|*|*|",
                        "|*|*|#|#|",
                        "|#|*|*|#|",
                        "|*|*|#|#|",
                        "|#|#|*|#|",
                        "|#|*|#|*|",
                        "|*|#|*|#|",
                        "|*|*|#|*|",
                        "|#|*|*|#|",
                        "|#|#|#|#|",
                        "|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome008() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|*|*|#|*|#|",
                        "|*|#|*|*|#|#|#|",
                        "|*|*|#|#|*|*|*|",
                        "|#|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome009() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|*|#|*|#|#|*|",
                        "|*|#|*|*|#|#|#|",
                        "|#|*|#|#|#|#|*|",
                        "|#|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome010() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|*| |#| |#|*|",
                        "|*| |*| |*|*|",
                        "|#|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome011() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |#|",
                        "| |*| | | |#|",
                        "|*|#|*| |*|#|",
                        "|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome012() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#| | | | | | |",
                        "| | |*|*| | | | | |",
                        "| |#|*|*|*| | | |*|",
                        "| |#|#|#|*|#|*| |#|",
                        "|#|#|*|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome013() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |*|#| | | | |",
                        "| | | | |*|#| | |*|*|",
                        "|#|*|*|*|#|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome014() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|*|#|#|#|#|",
                        "|#|*|*|#|*|*|*|#|",
                        "|*|#|*|*|#|*|#|#|",
                        "|*|#|#|#|*|*|*|*|",
                        "|#|#|*|*|#|*|#|*|",
                        "|#|*|*|#|#|#|*|#|",
                        "|#|*|*|*|*|#|*|*|",
                        "|#|*|*|*|#|#|*|#|",
                        "|*|#|#|#|#|*|#|*|",
                        "|#|*|*|*|#|*|#|#|",
                        "|*|#|#|#|#|#|*|*|",
                        "|*|*|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome015() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|#|#|#|#|*|#|",
                        "|#|#|*|*|#|*|*|*|*|",
                        "|*|*|#|*|#|*|#|#|#|",
                        "|*|#|*|#|*|*|#|*|*|",
                        "|#|#|#|#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome016() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | |*|#| | | |",
                        "| |#|#| |#|*|#| | |",
                        "| |*|#|*|#|*|*| | |",
                        "|*|#|*|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome017() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|*|#|*|*|*|#|#|*|",
                        "|#|#|*|*|#|#|#|*|#|",
                        "|*|*|#|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome018() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "|#| | | | | | | |",
                        "|*| | | | | | | |",
                        "|#| | |#| | | | |",
                        "|*|*| |*| |*|#| |",
                        "|#|#|*|#|*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome019() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | |#|",
                        "| | | | | | | |#|",
                        "| | | | | | | |*|",
                        "| | | | | | | |*|",
                        "| | | | | | | |#|",
                        "| |#| | |#|*| |#|",
                        "| |*| | |#|*| |*|",
                        "| |#|#| |#|*| |#|",
                        "| |*|*| |*|*|#|#|",
                        "|*|#|*| |#|#|#|*|",
                        "|*|*|#| |*|#|#|#|",
                        "|*|*|#| |*|*|*|*|",
                        "|#|#|#| |*|#|#|#|",
                        "|*|#|*|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome020() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |*| | | | | |*|",
                        "|#| | | |*|*| |#| | |#|"
                }
        );
    }

    @Test
    void calculateOutcome021() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |#| | | | | |",
                        "| | | | | |#| | | | | |",
                        "|*| |#|*| |*| |*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome022() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| |*| | | | | | | | |",
                        "|#|#|#|*|#| |*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome023() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|#| | | | | | | | | |",
                        "|*| | |#| |#|*|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome024() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | |",
                        "| | | | | | |*| |#| | | | |",
                        "|*| |*| |#|#|*| |#| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome025() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |*|#|#|*|*|*|*|*|#| |#|*|#|",
                        "| |#|*|*|#|*|#|#|#|#|*|#|#|*|",
                        "| |#|*|*|#|#|#|*|#|*|#|#|#|#|",
                        "|*|*|#|*|*|#|*|#|#|#|*|*|#|*|",
                        "|*|#|#|#|*|*|*|#|*|*|#|*|#|*|",
                        "|#|#|*|*|*|*|*|#|*|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome026() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | |",
                        "| |*| | | |#|*| |#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome027() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | |*| | | | | | | | | |",
                        "| | | |*| | | | | | | |#| |",
                        "| | | |#|#| |#|#| | |#|*| |",
                        "| | |#|#|*| |*|*| | |#|*| |",
                        "| |#|#|*|*|*|#|*|*| |#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome028() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | |*| | |#| | | | | | |",
                        "|#|*|#|*|*|*| | |*| |#| | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome029() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |#| |#| | | | |#| | | | |*|",
                        "| | | |*|*|#|#| |*| |*| | | |*|*|",
                        "| | | |#|*|#|#|*|#| |#| | |*|#|#|",
                        "| |*|#|*|*|#|*|*|*| |#|#| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome030() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |#| | | |",
                        "| | | | | | | | | | |#| | | |",
                        "| | | | | | | | | | |*| | |*|",
                        "| | | | | | | | | | |#| | |#|",
                        "| | |#| | | | | |#| |*| | |*|",
                        "|#|#|*|#|*| |*|*|#|*|*| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome031() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|*| | | | | | | | |#| | | | | |",
                        "|*|*| | |*| | |#|#|#|#| | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome032() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|#|",
                        "|*|*|*|#|*|",
                        "|#|#|#|*|*|",
                        "|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome033() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | |#| | | |",
                        "| | |*| | | |",
                        "|#| |#| | |#|",
                        "|*| |#| | |*|",
                        "|*|*|#|#| |*|",
                        "|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome034() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|*|",
                        "|#|*|#|*|",
                        "|*|*|*|*|",
                        "|#|#|*|#|",
                        "|*|*|#|*|",
                        "|#|#|*|#|",
                        "|#|#|#|*|",
                        "|#|*|*|#|",
                        "|#|*|#|*|",
                        "|*|#|*|*|",
                        "|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome035() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|#| | | | |",
                        "|*| | | | |",
                        "|#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome036() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | |#|",
                        "| | | |#|*| |*|",
                        "|#| | |#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome037() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |#| | |#| | | |",
                        "| |*|*| |#|*|#| |",
                        "|*|#|#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome038() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#| | | |",
                        "| |*|*| | | |",
                        "| |#|#| | | |",
                        "|*|#|*| | |#|",
                        "|*|*|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome039() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|*|#|#|*|",
                        "|#|#|#|#|*|*|*|",
                        "|#|#|#|#|*|*|#|",
                        "|*|*|#|*|*|#|*|",
                        "|*|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome040() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |#| | | |#|",
                        "|#| | | | |*| | | |*|",
                        "|#| | | |*|*| |#|#|*|",
                        "|#|*| |#|*|#|#|#|*|#|",
                        "|*|#| |*|#|#|*|#|*|*|",
                        "|#|*|*|*|#|*|*|#|#|*|",
                        "|*|#|*|#|*|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome041() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | |*| |",
                        "| | | | | | | | |*| |",
                        "| | | | | | | | |#| |",
                        "| |#| | | | | | |*|*|",
                        "|*|#| |#|#|#| | |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome042() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |*| | | |#|",
                        "| | | |#| |*|*|*|",
                        "|#|#| |*| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome043() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*| | | | | |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome044() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | |",
                        "| |#| | | | |#|#| |*| | |",
                        "| |#| | | | |#|*| |#| | |",
                        "| |*| | | |*|*|*|*|*| | |",
                        "|#|#| | |#|*|#|*|*|*| | |",
                        "|#|*|*|#|*|#|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome045() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | |",
                        "| | |*|#| | | | | |#| | |",
                        "| | |#|#| |#|#| | |*| | |",
                        "| |#|#|#| |*|*|*| |*| |*|",
                        "|*|*|#|*|#|#|*|#| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome046() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|#| | | | | | | | | |#|",
                        "|#|*|#|#|*| |*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome047() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |*| | | | | | |",
                        "| | | | |#| | |*| | | |",
                        "| | |#| |*| | |#| | | |",
                        "|#|*|#|#|*| | |#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome048() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |*|*| | |#|*| | | |",
                        "|*|*|*|#| |#|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome049() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | |*| | | | |",
                        "| | |*| | |#| |#| | |#|*|",
                        "| |*|*| |*|#|#|#| | |#|#|",
                        "| |#|*| |#|*|*|#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome050() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | |#| | | | | | | |",
                        "| | |#| | | | | |*| |",
                        "| |*|#| | |*| |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome051() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| |*| | | | | | | | | |",
                        "| |#| |#| | |#| | | | |",
                        "| |*|#|#| |*|*|*| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome052() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | |",
                        "| |*|#|#| | | | | |#| | | |*|",
                        "|*|*|#|#| | | | |*|#|*|#| |*|",
                        "|#|*|*|#|*| | |*|*|#|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome053() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | | | |",
                        "| | | |*|#|#| | | | | | | | |",
                        "| | |*|#|#|*|*| | |*| | | | |",
                        "|*|#|*|*|*|#|#| |#|*|#|#| | |",
                        "|#|#|#|#|*|*|*|*|*|#|*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome055() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |#|#| | | | | | | | | | |",
                        "| |#|*| | | | | | | | | | |",
                        "|#|*|#|*| | |*| | | | | | |",
                        "|#|*|#|*| | |*| | |*| | |*|",
                        "|#|*|#|#|#| |#|*|*|*|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome056() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | |#| | | | |",
                        "| | | | |*|*| | | | | |#| | | | |",
                        "| | | | |*|#| | | | |*|#| | | | |",
                        "| | | | |#|#| | | | |*|*| | | | |",
                        "|#|*| | |*|*| | | | |#|#| | | | |",
                        "|*|#| | |*|*| | | |*|*|*| | | | |",
                        "|#|*|#|#|*|#|*|#| |#|*|#| | |*|#|",
                        "|#|#|#|*|#|*|#|#|*|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome057() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | | | | |",
                        "| | | | |#| | | | | | | | | | | |",
                        "|*|#|#|*|*|*| |*| |#|#| |#| | |#|"
                }
        );
    }

    @Test
    void calculateOutcome058() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#|#| | | | | | | | | |*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome059() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |#| |",
                        "| | | |*| | |*|*| | |*| | |*|*|",
                        "|#| | |#| | |*|*| | |#| | |#|*|",
                        "|*| |#|#|#| |*|*|*| |#| |#|#|#|",
                        "|*|#|#|*|*|#|*|#|*|#|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome060() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| |#| |",
                        "|*|#| |",
                        "|#|#| |",
                        "|*|*|*|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome061() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome062() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |*| | | | | |",
                        "|#|#| | | | | | | |*| |*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome063() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| | | | |",
                        "| | | | | | | | | | | | |*| | | | |",
                        "| | | | | | | | | | | | |#| | | | |",
                        "|*| | | | | | | | | | | |*| | | | |",
                        "|*| | | | | | | |*| | | |*| | |#|*|",
                        "|#| |*| | | |*| |#|#| |#|*| | |#|*|",
                        "|*| |*| |#| |*| |*|#| |#|#| | |*|*|",
                        "|#|*|#| |#|*|*|#|#|#| |#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome064() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | |*| |",
                        "| | | | | | |#| |",
                        "| | | | | | |*| |",
                        "| | | | | | |*| |",
                        "| | | | | | |#| |",
                        "|#|#| | |#|#|#|*|",
                        "|#|*|*| |*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome065() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |*|#| |*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome066() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome067() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| |#| | | |#| |",
                        "| |#| |#|*|#| |",
                        "| |*| |*|#|*| |",
                        "| |#| |#|*|*| |",
                        "| |#| |*|#|*|*|",
                        "| |*| |#|#|#|*|",
                        "|*|#|*|#|*|*|*|",
                        "|#|*|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome068() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |*| |#| | | |",
                        "| | | | |#| |*| | | |",
                        "| | |#| |#|*|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome069() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome070() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "|#| | | | | | | | |",
                        "|*| | |#| | | | | |",
                        "|#| | |#|*| | | | |",
                        "|*| | |*|*| | | | |",
                        "|#|*| |#|*| |*| | |",
                        "|#|*| |#|#|#|#|#| |",
                        "|#|#|*|#|#|*|#|*|*|",
                        "|*|#|*|*|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome071() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | |#|",
                        "| | | | | | | | |*|",
                        "| |#| | | | |*| |#|",
                        "|#|#| |*|*|*|*|*|#|",
                        "|#|*|#|#|#|*|#|*|*|",
                        "|*|#|*|*|*|#|#|#|#|",
                        "|*|#|*|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome073() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|*|*|#|*|*|#|#|*|#|#|",
                        "|*|*|*|*|#|#|#|*|*|*|#|#|*|",
                        "|#|*|#|*|*|#|#|*|#|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome074() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| |*| | | | | | |#| | |",
                        "| |*| | | | | |#|#| | |",
                        "|*|*|#|*|#|*|#|#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome075() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|*| | | | | |#| | | | | |",
                        "|#| | | | | |*| |*| |#| |",
                        "|#| | | | | |*| |#| |*|*|",
                        "|*| | | | |*|*| |#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome076() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome077() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | |*| | |",
                        "| | | | | |*|#| | | | | |#| | |",
                        "| | |*| | |*|*| | | | | |#| | |",
                        "| |*|*| | |#|*| | | | | |*| | |",
                        "|*|*|#| | |*|*|#|#| |*| |*| |#|",
                        "|*|*|*|*|#|#|#|*|#|#|#|#|#| |#|",
                        "|#|*|*|*|#|#|#|#|#|*|#|*|#|#|*|",
                        "|#|#|*|*|#|*|#|*|#|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome078() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome079() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| |*|*|#|#| | | |*| | | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome080() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | | |#|",
                        "|#| |#| | |*|*| | | |*| | |*|",
                        "|#| |*| | |*|*|#|#|*|#| | |*|",
                        "|*| |*|#|*|#|#|#|*|#|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome081() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | |*| | | | | | |",
                        "| | | | | | | |#| |*| | | | |",
                        "|*| |*| |#| | |*| |#| | | |#|",
                        "|*| |*| |*|#| |#| |#| | | |*|",
                        "|*|*|#| |*|*|#|#| |#| |*|*|*|",
                        "|*|#|#|*|*|#|#|*| |#| |*|#|#|",
                        "|*|*|#|#|#|*|#|#| |*|#|#|*|#|",
                        "|*|#|*|*|*|#|*|*| |*|#|*|#|#|",
                        "|#|*|#|#|*|*|*|#|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome082() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | |#|*| |*| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome083() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|*| | | | | | |#| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome084() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | | | | |",
                        "|#|#| |#| | | | | |#| | | | | | |",
                        "|*|#| |#|*|*| | |*|#| |*| | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome085() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | |#| | |*| | | | | | |#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome086() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|*|*|*|*|*|#|#|#|#|*|#|*|",
                        "|#|*|*|*|#|#|#|*|#|*|*|#|*|#|*|",
                        "|#|#|#|*|*|#|#|*|*|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome087() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | | | | |",
                        "| | | | | | | | |#| | | | | | | |",
                        "|*|*|#| | | |#| |#| | | | | | | |",
                        "|#|*|#| | | |*| |*| | |*| | | | |",
                        "|*|#|*| | |#|#| |#| |#|*|#|*| | |",
                        "|*|*|#|#|#|#|#|#|#|*|*|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome088() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|*|#|*|",
                        "|#|#|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome090() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |#|",
                        "| | | | |*| | | | | | | | | | | |*|",
                        "| | | | |#| | | | | |*| | | | | |#|",
                        "| | | | |#| | | | | |*| | | | | |*|",
                        "| | | | |#| | | | | |#| |*| | | |#|",
                        "| | | | |#| | | | | |#| |*| | | |*|",
                        "| | | | |*| | |#| | |*| |*| | |#|#|",
                        "| |*| | |#| | |*|#|#|*| |*| | |*|*|",
                        "|#|#|*|#|#|*|*|*|*|#|*| |#| | |#|*|",
                        "|*|#|#|#|*|*|#|*|#|*|#| |*|*| |*|*|",
                        "|*|*|#|#|#|*|#|*|*|*|#|#|#|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome091() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | |",
                        "|#| | |",
                        "|*| |*|",
                        "|#| |#|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome092() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | | | |#|",
                        "|#|*| | | |#|",
                        "|*|*| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome093() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | | | | |",
                        "|#|#|#| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome094() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|#|",
                        "|*|#|#|*|",
                        "|#|*|*|*|",
                        "|#|#|#|#|",
                        "|*|*|#|*|",
                        "|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome095() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |*|",
                        "| |*| | |#|",
                        "|#|#| | |*|",
                        "|#|*| |#|#|",
                        "|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome096() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|*|*|#|*|#|#|*|",
                        "|*|*|#|*|*|#|#|*|#|#|",
                        "|*|#|*|#|#|*|#|*|*|*|",
                        "|*|#|#|*|#|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome097() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |#| | | | | |",
                        "| | | | | |#|*| |#| |#|",
                        "| |*| | | |*|#|*|*|#|#|",
                        "|#|*| |*|*|#|#|*|*|#|*|",
                        "|*|#|*|#|*|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome098() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| |#|*| |#| | |#| |",
                        "| |#|*| |*|*|*|*| |",
                        "|*|#|#|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome099() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | |*|",
                        "| | | | | | | | | |*|",
                        "| | | | | | | | | |*|",
                        "| | | | | | | | | |#|",
                        "| | | | | | |*| | |#|",
                        "| |*| |#| | |*| | |#|",
                        "| |*| |#| |#|#| |#|*|",
                        "| |*|#|#|*|#|*| |#|*|",
                        "| |#|*|#|*|#|*|#|*|*|",
                        "| |*|#|#|#|*|#|*|#|#|",
                        "|#|*|*|#|*|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome100() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | |",
                        "|*|*|#|*|*| | |#| |#|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome101() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |*|#| | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome102() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | |#| | | | | | | |",
                        "| | | |#| | | | | | | |",
                        "| | | |*| | | | | | | |",
                        "| | | |#| | | |*| | | |",
                        "| | | |#| | | |#| | | |",
                        "| |*| |*| | |*|*| |#|*|",
                        "|*|*| |#| |*|*|#| |#|#|",
                        "|*|*| |#| |#|*|*|#|#|#|",
                        "|*|#| |#| |*|*|*|*|#|#|",
                        "|#|*|#|#|*|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome103() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | |*| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome104() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "|#|*| |#| |*|*|*| | | |#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome105() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | |*|*|#| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome106() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | | |",
                        "|*|*| | |#|#|#| |*|#| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome107() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | |#|",
                        "| | |*|*|*|#| | | |#| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome108() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | | | | | |",
                        "|#| | | | | |*| | |#| | | |*| | | |",
                        "|#| | |#| |#|*| | |*| | | |*|*| | |",
                        "|#|*|#|#|*|*|#| |*|*|#|*|#|*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome109() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |#| | | |",
                        "| | | | | | |*| | | | |#| |*| |*| |",
                        "| | | |*|#|*|#|#|#|*| |*| |*| |*| |",
                        "| |*|#|*|#|#|#|#|*|*|#|#|*|#| |#|*|",
                        "|#|#|*|#|*|#|*|#|#|*|*|*|#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome110() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | |#| | | | | | | |",
                        "| | |#| |#| | | |*| | | | | | | |",
                        "|*|*|*| |*| |*| |#| |#| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome111() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | |#| | | | |",
                        "| |#| | | | | | | | | |*| | | | |",
                        "|*|*| |*| | | | | | | |#| | | | |",
                        "|#|#|#|#| |*| |*|*|#| |#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome112() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |*| |",
                        "| | |#|*|*|*| |#|#| |*| | | | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome113() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | | | | |",
                        "|*| |#|#| | | | |#| | | |*| | | | |",
                        "|#|#|*|#|#| | | |#| | | |#| | | |*|",
                        "|*|*|#|*|*|*| | |*|#| | |#| |#|*|*|",
                        "|#|*|#|*|#|#|*|*|*|*| |#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome114() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "|#| | | | | |#| | |#| | | |*|#|",
                        "|#| |*|*| |*|*|*| |#|#| | |*|#|",
                        "|#|#|#|*| |#|*|*|#|#|#| |#|#|*|",
                        "|#|*|*|*| |*|*|*|#|#|#|#|#|#|#|",
                        "|*|#|*|*|*|*|#|*|*|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome115() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | |*| | | |",
                        "| | |#| | | | | | | | | |#| |*| |",
                        "| | |*| | | | | | | | | |*| |#| |",
                        "| |#|*|*| |#| | | | | | |*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome116() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |#|",
                        "| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome117() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | |#| |",
                        "|*| |#| |",
                        "|#|*|#| |",
                        "|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome118() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "|#|#| |",
                        "|*|#| |",
                        "|#|*| |",
                        "|*|#| |",
                        "|*|*| |",
                        "|#|#|*|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|*|*|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome119() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|*| | |",
                        "|#| | |",
                        "|*| |*|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome121() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | |*| | |",
                        "| | | |#| | |",
                        "| | | |*| | |",
                        "| |#| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome122() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "|*| | | | |",
                        "|#| | | | |",
                        "|*| | |#| |",
                        "|*| |#|*| |",
                        "|#|#|#|*| |",
                        "|#|*|#|*|*|",
                        "|*|*|#|#|*|",
                        "|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome123() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | |",
                        "|#| |*| | |",
                        "|*| |#| | |",
                        "|*|*|*|#|#|",
                        "|*|#|*|#|*|",
                        "|*|*|#|#|#|",
                        "|#|*|*|#|#|",
                        "|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome124() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |#| | | |",
                        "|#| |*| |*| | |#|",
                        "|*|*|#| |*| |#|#|",
                        "|*|*|#|*|#| |*|*|",
                        "|#|#|#|*|*|*|#|*|",
                        "|*|#|#|*|#|*|*|#|",
                        "|*|#|*|#|#|#|#|#|",
                        "|#|#|*|*|*|*|#|#|",
                        "|*|*|*|*|#|#|#|#|",
                        "|*|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome125() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "|*| |*| |*|*| |*| |",
                        "|#| |*|#|#|*|#|*| |",
                        "|#| |#|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome127() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |#| | | | |",
                        "| | | |#| | | | |",
                        "|*| |*|#| | | | |",
                        "|*|#|*|*| | |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome128() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | |#|",
                        "| | | | | | |#|",
                        "| | | | | | |*|",
                        "|#| | |#| | |#|",
                        "|*|#| |#| |*|*|",
                        "|*|*|*|*|*|#|#|",
                        "|*|*|*|*|#|*|#|",
                        "|#|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome129() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| |*|*|*| |*| |*|",
                        "| |*|*|#| |*| |#|",
                        "| |*|#|#|#|#|#|#|",
                        "| |#|#|*|*|*|#|*|",
                        "|#|*|*|#|*|#|#|*|",
                        "|#|#|*|#|#|*|#|#|",
                        "|*|*|#|#|#|*|#|*|",
                        "|*|#|*|*|#|*|#|#|",
                        "|*|*|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome130() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "|#| | | | | |",
                        "|*| | | | | |",
                        "|#| | |*| | |",
                        "|*|#| |*| |#|",
                        "|#|*|#|*| |*|",
                        "|#|#|*|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome131() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| |#| | | |#|*|",
                        "| |*|#|#| |#|*|",
                        "| |*|#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome132() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |#| |",
                        "| | | | | | | |#| |",
                        "| | | | |#| |*|*| |",
                        "| | | | |*| |#|*| |",
                        "|*| | | |#| |#|*| |",
                        "|#|*| | |*|*|#|*| |",
                        "|#|#| | |#|#|*|#| |",
                        "|*|*|*|*|*|#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome133() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | |*|#| | | |#|#|*|",
                        "|#| |*|#|*|#|*|*|#|*|",
                        "|*| |#|*|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome134() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome135() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | |#| | |*| |",
                        "|#|*|#| |#| |*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome136() {
        check(GameOutcome.WIN_HASH, 8, new String[]{
                        "|*|*|#|*|*|*|*| |*|#|*|#|",
                        "|*|*|#|#|#|#|#|#|#|#|*|#|",
                        "|*|#|*|#|*|*|*|#|*|#|#|#|",
                        "|#|*|*|#|*|*|*|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome137() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | |",
                        "|*| | | | |#| | | | | | |",
                        "|*|#| | | |#| | | |*|*|#|",
                        "|*|#| | | |*| | | |*|*|#|",
                        "|#|#| | | |*|#| | |*|#|#|",
                        "|*|*|*| |#|*|*|*| |#|*|#|",
                        "|#|#|*| |#|#|*|#|#|*|#|#|",
                        "|#|#|*|*|*|*|*|*|#|*|*|#|",
                        "|*|#|*|#|*|#|#|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome138() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|*|#|*|*|#|#|*|",
                        "|#|*|#|#|*|#|#|#|#|#|",
                        "|*|*|#|*|#|*|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome139() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | |#| | | |",
                        "| | | | | | | |#| |*| |",
                        "| | | | | | | |#| |*| |",
                        "| | |*| |*| | |#| |*| |",
                        "| | |#|#|*|#| |*| |#| |",
                        "|#| |*|#|#|#| |#| |*| |",
                        "|*| |*|*|#|#|*|*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome140() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |*| |#|*| |#|#| | | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome141() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | | |",
                        "|*| | |*|*| |#| |#| |#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome142() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | |*|*| | | | |#| | | | |",
                        "| | |*|#| | | | |*| | | | |",
                        "| | |*|#| | | | |#| | | | |",
                        "| |#|*|*|#| | | |*| | | | |",
                        "| |*|#|#|*| | | |#| | | | |",
                        "|*|#|#|#|#| |*| |*|*| |*|#|",
                        "|#|*|#|*|*|#|#|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome143() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | |*|*| | | | |*| | | | |",
                        "| | |*|#| |#|#| |#| |#| | |",
                        "| |#|*|*| |#|#| |*| |*| | |",
                        "|*|*|#|*|#|*|#| |#|*|*|#| |",
                        "|#|*|#|*|*|#|*|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome144() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | |",
                        "| |*| | | | |#| | | | | | |",
                        "|*|#| | |#| |#|*|#| |*|#|*|",
                        "|#|#|#|*|*|#|*|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome145() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|#|*|*|*|*|*|#|*|#|*|*|#|",
                        "|#|#|#|#|*|#|*|#|#|#|#|#|#|*|",
                        "|*|*|#|#|#|#|#|*|*|#|*|*|#|*|",
                        "|*|#|#|#|*|#|*|*|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome146() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|*|#|#|*|#|*|#|*|#|#|#|",
                        "|*|#|#|#|*|#|*|*|#|#|*|*|",
                        "|#|*|*|*|#|*|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome147() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "| | | |#| | |#| | | | | | |",
                        "| |*| |#| | |*| | | | | | |",
                        "| |*| |*| | |*| | | | |#| |",
                        "|*|*| |*| | |#|#| | | |*| |",
                        "|*|*|#|#| | |*|#|*| | |*| |",
                        "|#|#|#|#|#| |*|*|*|#| |#| |",
                        "|#|*|*|#|#| |*|#|#|#|*|*|*|",
                        "|#|*|#|*|*|#|*|#|*|#|*|*|*|",
                        "|*|#|#|*|#|*|#|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome148() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |#| | | | |",
                        "| | | | | | | | | |*| |#| | | | |",
                        "| |#| | | | | | | |*|#|*|#| | | |",
                        "|#|*|*| |*|#| | | |*|*|#|#| | | |",
                        "|*|#|#| |*|*| | |#|*|*|#|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome149() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |*| | |*|",
                        "| | | | | | | | | | | | |*| | |#|",
                        "| | | | | | | | | | | | |*| | |#|",
                        "| | | | | | | | |*| |*|*|*| | |#|",
                        "| | | |*| | | | |*| |*|#|*| | |*|",
                        "| | | |#| |#| |#|#| |#|*|#| | |#|",
                        "| | | |*| |#| |#|*| |*|*|*| |#|#|",
                        "| | | |*| |*| |*|#| |*|*|*| |*|*|",
                        "| | | |#| |*| |#|*| |#|*|#| |*|#|",
                        "| |#|*|*| |#| |#|#|#|#|*|*| |*|#|",
                        "| |#|#|#|#|#|#|*|*|#|#|*|#|*|*|#|",
                        "|*|#|*|#|#|#|#|#|*|*|#|#|#|#|*|*|",
                        "|*|#|*|#|#|*|#|*|#|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome150() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| |*| | | | | | |*| | | | | |",
                        "| |#| | | | | | |#| | | | | |",
                        "| |*| | | | | | |#| | | | | |",
                        "| |*|#| |#| | | |*| | | | | |",
                        "|#|*|#| |*|#| |*|*| | | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome151() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |*|#|#|#| |#|#|#| | | | | |",
                        "|#| |#|#|*|*| |#|*|*| | |#| |#|",
                        "|*|*|#|#|*|*|#|#|*|*| |#|*| |#|",
                        "|#|#|#|*|*|*|*|#|*|*|*|#|*|*|#|",
                        "|*|*|#|*|#|*|#|#|*|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome152() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|*|#|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome153() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | |",
                        "|*| | |",
                        "|#| | |",
                        "|*| | |",
                        "|#| | |",
                        "|*|*| |",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome154() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | |#| | | |*| | | | | | | | |",
                        "|*|*| | |#| | |*|*|#| | | |#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome155() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | |*| | | |*| | | | | | | | | |",
                        "| | | |#| | | |*|#| |*| | | | | | |",
                        "| | | |#|*|*|#|#|#|#|*|*| | |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome157() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| |#|*| | |",
                        "|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome158() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome159() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | | |",
                        "|*| | | |",
                        "|*| | |*|",
                        "|*|#|#|*|",
                        "|#|#|*|#|",
                        "|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome160() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | |#|",
                        "| | | | | | | | |*|#|",
                        "| | |*| | | | | |#|*|",
                        "| | |*| | | | |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome161() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | |#| | | | | | | |",
                        "|*| |*| | |#|*| | | |",
                        "|#|*|#| | |#|*| | | |",
                        "|*|*|*| | |*|#|*|#| |",
                        "|#|#|#| | |#|*|#|*| |",
                        "|#|*|*| | |#|*|#|#| |",
                        "|*|#|*| | |*|*|*|*| |",
                        "|#|#|#|#|#|*|#|#|*| |",
                        "|*|#|#|*|*|*|#|#|#| |",
                        "|*|#|#|*|#|*|*|*|#|*|",
                        "|#|*|#|*|#|*|*|*|#|#|",
                        "|*|#|*|*|#|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome162() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |*|",
                        "|*| | | | | |#| |#|",
                        "|*| | | |#| |*| |#|",
                        "|*|#|*| |#| |*| |#|",
                        "|#|*|*| |*| |#| |#|",
                        "|*|#|#| |*|#|#|*|#|",
                        "|*|#|*|#|*|#|*|*|*|",
                        "|*|*|#|*|*|#|*|*|*|",
                        "|#|#|#|*|#|*|#|*|#|",
                        "|#|#|#|*|#|#|#|#|*|",
                        "|*|#|*|*|#|*|*|#|*|",
                        "|*|#|*|*|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome163() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | |*| | |#|*| | |",
                        "| | |#| | |*|*| |#|",
                        "|#|*|#| |*|#|*| |*|",
                        "|*|#|*| |#|#|#|*|#|",
                        "|*|#|*| |*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome165() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | |",
                        "| | | | | | | | | |#| | |",
                        "| | | | |#| | |*| |*|*| |",
                        "|*|*| |*|*|#|#|*| |#|#| |",
                        "|*|#|#|*|#|*|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome166() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|*|*|#|#|#|#|#|*|#|",
                        "|*|*|*|*|*|*|#|*|*|#|*|",
                        "|#|*|#|#|*|#|#|#|#|#|#|",
                        "|#|*|*|#|*|*|#|*|*|#|*|",
                        "|#|#|*|#|#|*|#|*|#|#|*|",
                        "|*|*|#|#|*|#|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome167() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | |#|",
                        "| | | | | | |*| | | |*|",
                        "| | | | | | |*| | |#|*|",
                        "| | |#| | | |*|#| |#|#|",
                        "|*| |#| |#|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome168() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | | |",
                        "| | | | | | |*| | | | | | | |",
                        "| | | | | | |*| | | | |#| | |",
                        "|#| |*| | | |*| | | |*|*| | |",
                        "|*|*|#| |#| |#|#|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome169() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |#|",
                        "| | | | | | | | | | | | | | |#|",
                        "| |*|*| |*|#| |#|*| |#|*| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome170() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |#|*| | | | | | | | |",
                        "|#|*| |*|*|*|*| | | |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome171() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | |",
                        "| | | | |#|*| |#| | |#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome172() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | | |#| | |",
                        "| | | | | |#| |*| | |*| | |#|*|#|",
                        "|#| | |#| |*| |#| | |#|#|*|*|*|#|",
                        "|*|#|*|#| |*|*|#|*|*|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome173() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| | | | | | |",
                        "| |#|#|#| | | |*|*| |#|*|#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome174() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |#|",
                        "| | | | | | |#| | | | | | | |#|",
                        "| | | | | | |*| |#| | | | | |*|",
                        "| | | | | | |#|#|*| | | | | |*|",
                        "| | |*|*|*| |#|#|*| | | | | |*|",
                        "| | |#|*|#|*|*|*|#| | |#|*| |#|",
                        "|*|#|#|*|#|#|*|*|#|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome175() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | | | | |",
                        "| | |*|*| | | | | | | | |*| | | |",
                        "|*| |*|#| | | | | | | | |#| | | |",
                        "|#|#|*|*|#| |*| |#|#|#|#|#|#|*| |",
                        "|#|#|*|*|*| |#|*|*|#|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome176() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | | | | |",
                        "|#| | | | |#|#|#| |*| |*| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome177() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| | | | | |",
                        "| | | | | | | | | | |#| | | | | |",
                        "| | | | | | | | | |*|*| | | | | |",
                        "| | |*|#|*| | |#|#|#|#| | | | |*|",
                        "|*|*|*|#|#|#|*|*|#|*|*| |#| |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome178() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| |*| | |",
                        "| |#| | | | | |#| | |*| |*| | |",
                        "| |#| |*| | | |*| | |*| |#| | |",
                        "|#|*|#|*| |#| |*| | |#|*|*| | |",
                        "|*|#|#|#| |*|#|#|#|#|#|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome179() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | |*| |#| | | | | | | |",
                        "| | | | | |#| |*| |*| | | | |#|",
                        "|*| | | |#|*| |#| |#| | | | |*|",
                        "|#|#|*|*|*|#| |*|#|#| |*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome180() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| |*| |",
                        "| |#| |",
                        "| |#|#|",
                        "| |*|#|",
                        "|*|#|*|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome181() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome182() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | |*| | | | |",
                        "| |#| | | | | | |*| | | |*| |*| | |",
                        "| |#|#| | |*| |#|*| | |#|#|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome183() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome184() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|*|*|",
                        "|*|#|*|#|#|",
                        "|*|#|#|#|*|",
                        "|#|*|*|*|#|",
                        "|*|#|*|#|*|",
                        "|#|#|#|*|*|",
                        "|*|#|*|*|*|",
                        "|#|*|#|#|#|",
                        "|#|*|*|#|*|",
                        "|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome185() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | |*|",
                        "| | | |#| |#|",
                        "| | |#|#| |#|",
                        "| | |*|#| |*|",
                        "| |*|#|*| |#|",
                        "|*|*|*|#| |*|",
                        "|#|*|*|#|#|#|",
                        "|#|*|#|*|*|*|",
                        "|#|*|*|#|*|#|",
                        "|*|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome186() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | |",
                        "| |#| | |",
                        "| |#| | |",
                        "| |*|*| |",
                        "| |#|*|*|",
                        "| |*|#|#|",
                        "| |#|*|*|",
                        "|#|#|*|*|",
                        "|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome188() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|*|*|*|#|*|#|",
                        "|#|*|#|*|#|*|#|#|",
                        "|#|#|#|*|*|*|*|#|",
                        "|*|#|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome189() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |*| | | |",
                        "|#| | |*|#| | | |",
                        "|*| | |*|*| |#| |",
                        "|#|*|#|*|#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome190() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|*|#|*|",
                        "|*|*|#|#|#|*|",
                        "|#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome191() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | |#| | |",
                        "| | | | |#| | |",
                        "| |#| | |*| | |",
                        "|#|*|*|*|*|#| |",
                        "|*|#|#|*|*|*| |",
                        "|*|#|*|*|#|#| |",
                        "|#|#|#|#|#|*|*|",
                        "|#|#|*|*|*|#|*|",
                        "|#|*|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome192() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | |",
                        "| | | | |#| | | | | | | |",
                        "| | | | |*| | | | |*| | |",
                        "| | | | |*| | | | |#| | |",
                        "| | | |#|#| | | | |*| |*|",
                        "|#|*|#|#|#|#|#|*| |*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome193() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | |",
                        "| | | | | | | | |#|*| | | |",
                        "| | | | | | | | |#|*|#| |#|",
                        "| | | | | | | |*|*|*|*|*|#|",
                        "| | | | |#| | |*|*|#|#|#|*|",
                        "| | | | |#| | |#|*|#|#|*|*|",
                        "|#|*|#|*|*| | |*|#|#|#|*|#|",
                        "|*|#|#|#|#| |*|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome194() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome195() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| |",
                        "| | | | |#| | | | | |*| |",
                        "| | |*| |*| |#|#|#| |*|#|",
                        "|#| |#| |#|*|*|*|#| |#|*|",
                        "|#|*|#|*|#|*|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome196() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |",
                        "| |#| | | | | | | | |*|*| | | |",
                        "|#|#| | |#| | | | |*|*|*| | | |",
                        "|#|#|*|*|*|#|*|*|*|#|#|*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome197() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome198() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |*|",
                        "| | | | | |#| | |#| | |#|*|",
                        "| | |#|*|*|*| | |#|*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome199() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | |",
                        "| | | | |*| | |#| | | | |*| |",
                        "| |#| | |#| |*|#| | | | |*| |",
                        "| |#|#|*|*| |#|#|*| | | |*| |",
                        "| |#|#|*|*| |*|*|*| | |*|*|#|",
                        "|#|#|#|*|#|*|#|*|#| | |*|#|#|",
                        "|#|*|*|*|#|#|*|#|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome200() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |*| | | | | |",
                        "| | |#| |#| | | | | | |*| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome201() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | | | | |",
                        "| |#|#| | | | | | | | | | |*| | |#|",
                        "|*|*|#|#|*| |*|*| |*|*|*|#|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome202() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | |*| | | | |*| | | | | | |#| |",
                        "|*| |#|#| | | |#|#| | |*| |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome203() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | | | | |",
                        "| | | | |*| |#| | | | | | |*| | |",
                        "|#| | | |*| |*|#| | | | |*|*| | |",
                        "|*| |#|#|#| |#|*|#| | | |#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome204() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome205() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |*|",
                        "| | | |#|",
                        "| | | |*|",
                        "| | | |#|",
                        "| |#|*|*|",
                        "| |#|*|*|",
                        "| |#|#|*|",
                        "|#|#|*|#|",
                        "|#|*|*|*|",
                        "|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome206() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| |#| |",
                        "| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome207() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome208() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | |#|"
                }
        );
    }

    @Test
    void calculateOutcome209() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|#|",
                        "|*|#|#|*|",
                        "|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome210() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |#| | | | | | |*|",
                        "|*| | |*| | | |*| |#|#| | |#| |#|#|",
                        "|#|*|#|#|*| |#|*| |*|*|#| |*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome211() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | |",
                        "| |#| |",
                        "| |*| |",
                        "| |*| |",
                        "| |#| |",
                        "| |*| |",
                        "| |#| |",
                        "| |*|*|",
                        "| |#|#|",
                        "|#|*|*|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|#|#|#|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|#|#|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome212() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |",
                        "|#| | | | | |",
                        "|*| |#|*| | |",
                        "|*|#|*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome213() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |*|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome214() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|*| | |#| |",
                        "|#| | |*| |",
                        "|#| | |*| |",
                        "|*| | |#| |",
                        "|#| | |*| |",
                        "|#|*| |#| |",
                        "|#|#| |#| |",
                        "|*|*|*|*|#|",
                        "|#|*|#|*|*|",
                        "|#|#|*|*|#|",
                        "|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome215() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|#| | | | |",
                        "|*| | | | |",
                        "|#| |*|*| |",
                        "|#|*|#|*| |",
                        "|#|#|#|*|#|",
                        "|*|*|#|*|*|",
                        "|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome216() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | |*|",
                        "|#| |*|#| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome217() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| | |",
                        "| | | | | |*|*| |",
                        "|#|*| |*|#|#|*|#|",
                        "|#|#|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome218() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|#|*|*|",
                        "|*|#|#|*|*|*|*|",
                        "|#|#|*|#|#|#|*|",
                        "|*|*|*|#|#|#|#|",
                        "|#|*|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome219() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |#| | | |*|",
                        "| | |*|#|#| |*|",
                        "|*|*|#|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome220() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | |*| | |",
                        "|*| | | | | | |#| | |",
                        "|*|#| |#| | |*|#| | |",
                        "|*|#| |*|*|*|#|*| |*|",
                        "|#|*|#|#|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome221() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | |*|#| |*| |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome222() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |*| | | | | |",
                        "| | | |#| | | | | |",
                        "| | | |*| | | |*| |",
                        "| | | |*| |#| |#|#|",
                        "|*| | |#| |#| |#|*|",
                        "|*|*| |#|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome223() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | |*| | | | |",
                        "|#| | | |#|*| | | | |",
                        "|#| |#| |*|*| |*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome224() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|#|#|#|*|*|*|#|*|*|*|*|*|",
                        "|#|*|#|#|#|*|#|*|*|#|#|*|#|#|*|",
                        "|#|#|#|*|#|#|#|#|*|#|*|*|#|*|#|",
                        "|*|#|*|*|#|*|*|*|*|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome225() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | | |",
                        "|#| |#| | | | | | | |*| | | | |",
                        "|#| |#|*| | |#|#| | |*| |*| | |",
                        "|#|*|*|#|*| |#|*| |*|#| |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome226() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|*|#|#|#|*|*|*|*|*|*|#|*|",
                        "|*|*|*|#|#|#|#|#|#|*|#|*|#|*|",
                        "|#|*|*|*|*|#|*|#|#|#|#|#|*|*|",
                        "|#|#|#|#|*|#|*|#|*|#|#|*|*|#|",
                        "|*|*|#|*|*|#|#|*|#|*|*|*|*|*|",
                        "|#|#|#|*|#|#|*|*|#|#|#|*|*|#|",
                        "|#|*|*|*|#|*|#|#|*|#|#|#|#|#|",
                        "|*|*|#|*|*|*|#|#|#|*|#|*|#|#|",
                        "|#|#|#|*|*|*|*|#|*|#|*|#|#|*|",
                        "|#|*|#|*|#|#|*|*|*|*|*|#|#|#|",
                        "|#|*|*|#|#|*|#|*|*|#|#|*|*|*|",
                        "|*|#|*|#|*|*|*|#|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome227() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | |",
                        "| | |#|*| |*| |#| |#| | | |#|",
                        "|#|#|#|*| |#| |#| |*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome228() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| | | |*| | |",
                        "| |#| | |#| |*|*| |#|#|#|*|*|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome229() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | |",
                        "| | | |",
                        "| |*| |",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome230() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |*| | |",
                        "| | | | | | | | | | | | | |#| | |",
                        "| |*| | |*| | | | | | | |#|#|#| |",
                        "|#|#| |*|#| |*|*| |*|#|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome231() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | |*| |*| | |*| | | | | | | |",
                        "|#|#|#|#|*| |#|*|*|#| | | | |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome232() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| |*|*| |",
                        "| |#|#|#|",
                        "|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome233() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | |#| |",
                        "| | | |#| |",
                        "| | | |*| |",
                        "| | | |*| |",
                        "|#| | |*| |",
                        "|#| | |#| |",
                        "|*| | |*| |",
                        "|#| |#|*| |",
                        "|*| |#|#| |",
                        "|*|*|*|*|*|",
                        "|#|*|*|#|#|",
                        "|*|#|#|*|#|",
                        "|#|*|#|#|#|",
                        "|#|#|*|*|*|",
                        "|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome234() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | |#|",
                        "|*|#|#|",
                        "|*|#|*|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome235() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome236() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | |#| |",
                        "| | | | |#|*| |",
                        "|#| |*| |*|#|*|",
                        "|*|#|#| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome237() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | |*| |",
                        "|*|*| | |#|*|#|",
                        "|#|#|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome239() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | |*| |",
                        "| | |#| |#|*|",
                        "| |#|*| |*|#|",
                        "| |*|*| |#|*|",
                        "|#|#|#|#|#|*|",
                        "|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome240() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|*|*|*|",
                        "|#|#|#|#|#|#|",
                        "|*|#|#|#|#|*|",
                        "|*|*|#|*|*|*|",
                        "|#|#|#|*|#|*|",
                        "|#|#|*|*|#|*|",
                        "|#|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome242() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |#| |",
                        "| |*| |#| |",
                        "|*|*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome243() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*|#| | | |#|",
                        "|#|*| | | |#|",
                        "|*|*| | |*|#|",
                        "|#|#| |#|*|#|",
                        "|*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome244() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | |*| |#| | | |",
                        "| | |#|#|#| |*| |",
                        "| | |*|*|*|#|#| |",
                        "| |*|*|*|#|*|*| |",
                        "| |#|*|#|*|#|#|#|",
                        "|*|#|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome245() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |#| | | | | |",
                        "| | | |#| | | | | |",
                        "| | | |#| | |#| | |",
                        "| |*| |#| | |#| | |",
                        "| |*| |#| |*|#| | |",
                        "| |#|#|*| |*|#| | |",
                        "|*|*|*|#|*|#|*|*| |",
                        "|#|#|*|#|*|#|*|#|*|",
                        "|#|#|*|*|#|#|*|*|*|",
                        "|*|#|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome246() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|#| | |#| | | |",
                        "|*|*| |#| | | |",
                        "|#|#| |#|*| | |",
                        "|*|#|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome248() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|*| |#| | | | | | | | |",
                        "|#| |#| | | | | |#| | |",
                        "|*| |#|*|*| | | |*| | |",
                        "|*| |#|#|#| |*|#|*|#|*|",
                        "|#|#|*|*|*|#|*|*|*|#|#|",
                        "|#|#|#|*|*|#|*|#|*|*|*|",
                        "|#|*|*|#|*|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome249() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "|#| | | | | | | | | | |",
                        "|*| | | | | | | | |*| |",
                        "|#| | |#| | | | | |*| |",
                        "|#| |*|*| | |*| | |*| |",
                        "|#| |#|*| | |#| | |*|*|",
                        "|*|*|#|*|#|#|#|#|#|#|#|",
                        "|*|*|*|*|#|#|*|*|#|*|#|",
                        "|*|#|*|*|*|#|#|*|*|*|*|",
                        "|*|#|#|#|#|#|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome251() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |*| | | |#|#|",
                        "| |*| |#|*| | | |*|*|",
                        "| |#| |#|*| | | |#|*|",
                        "| |#| |*|*| |*| |*|#|",
                        "| |#|#|#|*|#|*| |*|#|",
                        "|*|*|#|*|#|#|*|#|*|*|",
                        "|#|#|#|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome252() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | | | | |*|",
                        "| | |#| | | | | | | | | |*|",
                        "| | |*| | | | | | | | | |#|",
                        "| | |#| | | |#| | | | | |#|",
                        "| |#|#| | | |#| | | | |#|#|",
                        "| |*|*| | | |*| |*| | |#|*|",
                        "| |#|*| | | |#| |*| | |*|*|",
                        "|#|*|#| | | |#| |*| |*|*|#|",
                        "|*|#|*| | |*|#| |*|*|#|*|#|",
                        "|#|#|#| | |#|#|*|*|*|#|#|*|",
                        "|*|#|*|*|*|#|*|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome253() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |#|*| | | | | | | |*|",
                        "|*| | |*|#| |#| | | | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome254() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|*|#| | |#| |#| |#|#| | |",
                        "|*|#| | |#|#|*|*|*|#|*|*|",
                        "|*|#|*|*|#|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome255() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | |",
                        "|#| | |*| |#| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome256() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | |",
                        "| | | | | | | | | |*| |#|",
                        "| |#|*| | |*| | | |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome257() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | |#| | | |",
                        "| | | | | | | | |*| | | |",
                        "|#| | | | | | | |#| | | |",
                        "|#| |*| | | | | |*| | | |",
                        "|*| |#|*| |#| | |#|*| |*|",
                        "|#|#|*|#|*|*| |#|*|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome258() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|*| | | | | | | | | | |",
                        "|#| | | | | | | | | | |",
                        "|#| | | |*| | |*| | |*|",
                        "|#|#| | |#| | |#| |#|#|",
                        "|*|*| | |*|#| |*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome259() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | |#| | | | |",
                        "| | | | | |*|#| | | | |",
                        "| | |*| | |#|#| | | | |",
                        "| | |#| | |#|#| | | | |",
                        "| | |*| | |*|#| |#| | |",
                        "| | |#| |*|*|#| |*| | |",
                        "|*| |*| |#|#|*|*|*| |*|",
                        "|#|#|#|*|*|*|*|*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome260() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | |#| |*| | | | |",
                        "| | | |#| | |#|*| |*|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome261() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| |#| | |",
                        "|*|#| | | | | | | |*| |*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome262() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "|#|#| |*| | |*| |*| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome263() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|*| |*| | | | | | | | | | |",
                        "|*| |#| | | |#|#| | | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome264() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | | |",
                        "| |#| | |#| | | | | | | | | | |*|",
                        "| |*|#| |*| | | |#| | |*| |#| |#|",
                        "|#|#|#| |#|*| |*|*| | |#| |*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome265() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |#| | | |",
                        "|*| | | | | | | | | | | | |#| | | |",
                        "|*| | | | | | | | | | | | |*| | | |",
                        "|*| | | |*| | |*| | |#| | |#| |*|#|",
                        "|*| |*|*|#|#|#|#| |#|#|*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome266() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome267() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | |*| | | | |",
                        "| | | |*| | | | | | |#|*| | | | |",
                        "| | |#|*| |#| | | | |#|#| | | |#|",
                        "|#| |*|*| |#|#|*| | |*|*| |#| |#|",
                        "|#|*|*|#|*|*|#|*|#|*|#|*|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome268() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|*| | |",
                        "|*| | |",
                        "|*| | |",
                        "|#|#| |",
                        "|*|#| |",
                        "|#|#| |",
                        "|*|#| |",
                        "|#|*| |",
                        "|*|#| |",
                        "|*|*|*|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome269() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|*|",
                        "|*|*|#|#|",
                        "|#|#|#|#|",
                        "|*|*|#|*|",
                        "|*|*|#|#|",
                        "|#|*|#|*|",
                        "|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome270() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | |*| | | | | |",
                        "| | | | | |#| | | | | |*| | | | | |",
                        "|#|#| |#| |*|*| | |*|*|#| |*|#| | |",
                        "|#|#|*|*|#|#|*|#| |*|#|*| |#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome271() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | |*|",
                        "| | |*|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome272() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome273() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|",
                        "|*|*|*|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|#|*|#|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|*|*|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome274() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|*|#|*|*|#|*|#|*|*|#|*|#|*|*|",
                        "|#|*|#|#|#|*|#|*|*|#|#|#|*|#|*|*|#|",
                        "|#|#|#|*|*|*|*|*|#|#|*|*|#|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome275() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |*| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome276() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome277() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| |#| | | |",
                        "|#| |*| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome278() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |*|",
                        "|#| | |#|",
                        "|*| | |*|",
                        "|#| | |#|",
                        "|*|*|#|*|",
                        "|#|#|#|#|",
                        "|*|#|*|*|",
                        "|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome279() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|#|#|",
                        "|*|#|#|*|*|",
                        "|*|#|#|#|#|",
                        "|*|#|*|*|*|",
                        "|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome280() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| |*| | | | | |",
                        "|#|*| | |#| |#|",
                        "|*|*| |#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome281() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | |#| | | |",
                        "|*| | |*|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome282() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|#|*|#|#|",
                        "|*|#|*|#|#|*|",
                        "|#|#|#|*|#|*|",
                        "|#|*|*|#|*|*|",
                        "|*|#|*|#|*|#|",
                        "|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome283() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| |*| | | | | |",
                        "|#|#| | | |#| |",
                        "|#|#| | |#|*|*|",
                        "|#|*|*| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome284() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | |#| | | | |",
                        "| | | | | |*| | | | |",
                        "|#| | | |*|#| | | | |",
                        "|#| | |*|*|*| |*| | |",
                        "|*|#| |*|*|*| |#| |#|",
                        "|#|*|#|#|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome285() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | |*|",
                        "| | |#| | | | |*| |#|",
                        "| | |*| | |*| |#|#|*|",
                        "| |*|#|*| |*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome286() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |*| | | | |",
                        "| | | |*| | | | |",
                        "| |*| |*| |*|#| |",
                        "| |#|#|*| |*|*|#|",
                        "|*|*|#|*| |#|*|#|",
                        "|#|#|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome287() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | |#| | | | |",
                        "| |*| |*|#| | | |*|",
                        "|#|#| |*|#|#|*| |*|",
                        "|#|#| |*|*|#|*|*|*|",
                        "|#|#| |*|#|*|#|#|*|",
                        "|*|#|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome288() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | |",
                        "|#| |*| | |#| | | | | | | | |",
                        "|#| |*| |*|#| | | | |*| |*| |",
                        "|*| |*|*|#|#| |*| |#|#|#|#| |",
                        "|*|*|*|#|#|#| |#|#|*|#|*|*| |",
                        "|*|#|*|*|*|*| |*|*|#|*|#|#| |",
                        "|#|#|#|*|#|#| |*|*|#|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome289() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |#|",
                        "| | |*| | | | |#| | | | | |*|#|",
                        "| | |*| | | | |#|*| |#| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome290() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | | |",
                        "| |*| |*| | | | | | | | | |",
                        "| |*| |#| | | | | | | | | |",
                        "| |*|#|#|*| | |*| | | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome291() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | |",
                        "|*|#| | | |*| | | | | | |#| |",
                        "|#|*| | | |#| | | | | | |*| |",
                        "|*|#|#|#|*|*| | | | | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome292() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | | | | |",
                        "|*|*| | | |*| |#|#| | | | | | | | |",
                        "|*|*|#|#| |*| |#|*|#|#| | | | | | |",
                        "|#|*|#|*|*|#| |#|*|#|#| | |*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome293() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | | | | |",
                        "| | |*| | |*| | |#| | |#| | | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome294() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "| | | | | | | |*| | | | | |*| |",
                        "| | |#|*| | |*|*| | |#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome295() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | | | | |",
                        "| | | | |*|#|#|#|#| | | |*|*| | |",
                        "|#| |#| |#|#|*|*|#|*| |#|*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome296() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | | |",
                        "|#| | | |",
                        "|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome297() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| | | |",
                        "|*| | | |",
                        "|#| | |*|",
                        "|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome298() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| |*| |",
                        "| |#| |",
                        "|#|*| |",
                        "|#|#| |",
                        "|#|*|*|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome299() {
        check(GameOutcome.TIE, 4, new String[]{
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|#|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome301() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |*|",
                        "| | | | | |#|",
                        "| | | | | |*|",
                        "| | | |*| |#|",
                        "|#| | |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome302() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |#|",
                        "| | | | |#|",
                        "| | |*| |*|",
                        "| | |*|#|#|",
                        "|#|*|#|*|*|",
                        "|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome303() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |#| |",
                        "| | | |#| |",
                        "| | | |*| |",
                        "| | |*|#|*|",
                        "|#| |#|#|#|",
                        "|*| |*|#|#|",
                        "|*| |*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome305() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |#| | | | |",
                        "| |#| | | | |",
                        "| |#|*|*| | |",
                        "| |#|*|#| | |",
                        "|#|#|*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome307() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | |*| | |",
                        "| | |*| | |",
                        "| | |#| |#|",
                        "| | |*| |#|",
                        "|*| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome309() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |*| |*| | |",
                        "| | | |#| |*|*| |",
                        "|*|#| |*| |#|*| |",
                        "|#|*|#|#|#|#|*|*|",
                        "|*|#|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome310() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |*|#| | |",
                        "| |*| |*|#| |#|",
                        "|*|*|*|#|*| |#|",
                        "|*|#|#|#|#| |#|",
                        "|*|#|*|*|*|#|#|",
                        "|*|*|#|*|#|#|*|",
                        "|*|#|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome311() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | |*| |",
                        "| | | | | |#| |",
                        "| | | | |#|*|*|",
                        "| | | | |*|#|*|",
                        "|*|#| |#|#|#|*|",
                        "|#|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome312() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | |#|*|",
                        "|*| | | | | | | |#|*|",
                        "|*| |#|*|*| | | |#|*|",
                        "|*| |#|*|*|#|#| |#|*|",
                        "|#| |#|#|#|#|#| |#|#|",
                        "|#| |#|*|*|*|#|*|*|*|",
                        "|#|#|*|*|#|#|*|#|*|*|",
                        "|#|*|*|*|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome313() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|*|#|#|*|#|#|#|*|*|",
                        "|*|*|#|*|#|*|#|#|#|#|",
                        "|#|*|#|#|#|*|*|*|#|*|",
                        "|#|#|*|*|*|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome314() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|*|#|#|*|*|#|*|",
                        "|*|*|*|#|#|#|#|*|#|",
                        "|#|*|*|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome315() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|*|*|#|*|#|*|*|*|",
                        "|#|#|#|*|#|#|*|#|#|",
                        "|*|*|#|*|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome316() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| | | | | | | | | | | |",
                        "|#| | | |*| |*| | | | | |",
                        "|#| |#| |#| |*|*| | |#| |",
                        "|#| |*| |*|#|*|#| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome317() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| | | | | | | | |#| | |",
                        "| |*| | |#| | | | | |*| | |",
                        "|*|*|*| |*| | | |#|#|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome318() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|*|#| |#| | | | |*| |*|",
                        "|*|*|*|#| | |#| |#| |#|",
                        "|#|*|*|#|#|*|*| |*|*|#|",
                        "|#|#|*|*|*|#|#| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome319() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | |",
                        "|*| | | | | | | | | | | |",
                        "|*| | | | | | |#| | | |*|",
                        "|*| | | | | | |*| | | |#|",
                        "|#| |#| | |*| |*| |#|#|*|",
                        "|*|*|*|#| |#| |*| |#|#|#|",
                        "|*|*|*|#| |#|#|*|#|#|*|*|",
                        "|#|#|*|#| |#|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome320() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | |#| |*| | | | |",
                        "| |#| | | | | | | | |#|*|*| | |#| |",
                        "| |#| | |#|#| |#| | |*|*|*| |*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome321() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | | | |",
                        "| | | | | | | |*| | | | | | | | | |",
                        "|#|*| |#| |*| |#|*| | | |*| | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome322() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome323() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | |*| | |*| | | | | |",
                        "| | |#| | | |#|#|#|#|#|*| | | | |",
                        "| | |*| | |*|#|*|#|*|*|#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome324() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome325() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome326() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|#|#|*|",
                        "|*|*|*|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome327() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| |*| | |",
                        "|#|#| | |",
                        "|#|#|*|*|",
                        "|#|*|*|*|",
                        "|#|#|#|#|",
                        "|#|*|#|#|",
                        "|*|*|*|*|",
                        "|*|*|#|*|",
                        "|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome328() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|*|*|*|",
                        "|*|#|#|#|#|#|",
                        "|#|*|#|*|*|*|",
                        "|*|#|#|*|#|*|",
                        "|*|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome329() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |*| | | |",
                        "| | |#|#| | | |",
                        "| | |#|#| | | |",
                        "|*|*|*|*| |*| |",
                        "|#|*|*|*| |#| |",
                        "|*|#|#|*|#|*| |",
                        "|#|*|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome330() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|#|#|",
                        "|#|#|#|*|#|",
                        "|#|*|*|*|*|",
                        "|*|#|#|*|*|",
                        "|*|*|*|#|#|",
                        "|#|*|#|*|*|",
                        "|#|*|*|*|*|",
                        "|#|*|#|*|*|",
                        "|#|#|#|#|#|",
                        "|*|#|*|*|#|",
                        "|#|*|*|*|#|",
                        "|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome331() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |",
                        "|#| | | | | |",
                        "|#|#| | | | |",
                        "|*|*| |*| | |",
                        "|#|#|*|*|*| |",
                        "|#|#|#|*|*|#|",
                        "|*|*|*|#|#|#|",
                        "|#|*|#|*|#|*|",
                        "|*|#|#|#|#|*|",
                        "|*|#|*|*|#|#|",
                        "|*|#|*|*|*|#|",
                        "|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome332() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome333() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |#| |",
                        "| | | | | | | |*| |",
                        "| | | | | | | |*|*|",
                        "|#|#|#| | | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome334() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |#| |*|",
                        "| | | | |#|*|#|",
                        "| |#|*|#|*|#|*|",
                        "|*|*|#|*|#|*|*|",
                        "|*|#|*|*|*|#|#|",
                        "|#|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome335() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | |*| |*| |",
                        "| | |*| |*| |#| |",
                        "|*|#|*| |#|*|#| |",
                        "|#|#|#| |*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome336() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "|*| |#|#| | |*|*|",
                        "|*| |#|#|#|#|#|*|",
                        "|#|*|*|#|#|#|*|*|",
                        "|*|#|*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome337() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | |",
                        "| |#| | | | | |#| |",
                        "| |*| | | | | |#|#|",
                        "| |#|*| |*|*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome338() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#| | | | |",
                        "|*|#|*|#|*|*|#|",
                        "|*|*|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome339() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| | |",
                        "| | | | | |#| | |",
                        "| |*|#| | |*|*| |",
                        "| |*|*| | |#|*| |",
                        "| |#|#|#|*|#|*|#|",
                        "|#|*|*|#|*|#|*|#|",
                        "|*|*|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome340() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |#| | |*| | |",
                        "| |*| |*|#| | |*|#| |",
                        "| |*| |#|*| | |*|*| |",
                        "|#|*|#|#|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome341() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|#| |#| | | | | | | | |",
                        "|*|*|*| | |#| | | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome342() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |*| |",
                        "| |#| | | | | |*| |",
                        "| |#| | | | | |#| |",
                        "| |*| | | | |#|#| |",
                        "|*|#| | | | |*|*| |",
                        "|*|*| | |#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome343() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|*|*|*|*|#|#|*|",
                        "|*|*|#|#|#|#|*|*|#|#|",
                        "|#|#|*|*|#|*|*|*|#|#|",
                        "|#|*|*|#|#|*|#|#|*|*|",
                        "|#|*|*|*|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome344() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |#|*| | | | |#| |#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome345() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | |",
                        "| |#|#| | | |#| | |*| | | |",
                        "| |#|*| | |#|*|*| |*| | | |",
                        "|*|*|#|#| |*|*|#|#|#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome346() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |*| | | | | | |#| |",
                        "|*| |*|#|#| | | |*|#| |",
                        "|*|#|#|*|#| |*| |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome347() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | |",
                        "| | | |#| | | | | | | | |",
                        "| | | |#| | | | | | | | |",
                        "|*| | |*| | | | | | | | |",
                        "|*| | |#| | | |#| | | |#|",
                        "|#| |#|*| |*| |*| | | |*|",
                        "|#|#|#|*|#|*| |*| |*| |#|",
                        "|*|*|*|#|*|#| |#| |*| |#|",
                        "|#|#|#|#|#|*| |*|*|#| |#|",
                        "|#|*|#|#|*|#|#|#|*|*| |#|",
                        "|#|*|*|*|*|#|#|*|#|*| |*|",
                        "|*|*|*|#|#|*|*|*|#|*| |*|",
                        "|#|#|*|#|#|*|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome348() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | |*|#| | | |#| |*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome350() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | | | |",
                        "| | | | | | |*| | |#| | | | |",
                        "| | |*| | | |*| | |#| |#|#| |",
                        "|*|#|#| | | |*|*|*|*| |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome351() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | |*| | |",
                        "| | |*| | |#| | | | | |*| | |",
                        "| | |*| | |*| | | |*| |#| |#|",
                        "| | |#|*|#|#| | | |#| |*|#|*|",
                        "| | |*|#|#|*|*| | |#| |#|#|#|",
                        "|*|*|*|*|#|#|#| |*|*| |*|#|*|",
                        "|#|#|#|*|#|*|*|#|#|*|*|#|*|*|",
                        "|*|#|*|#|#|*|*|#|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome352() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |*| |",
                        "| | | |#| |",
                        "| |#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome353() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |#| |",
                        "| | | |#| |",
                        "| |*| |#| |",
                        "|*|*|*|*| |",
                        "|#|#|*|#| |",
                        "|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome354() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|#|*|#|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|#|#|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome355() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | |#|"
                }
        );
    }

    @Test
    void calculateOutcome356() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |*| | | |",
                        "| |#| |*| | | |",
                        "|#|#|#|#| | | |",
                        "|#|*|#|*| |*|#|",
                        "|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome358() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | |*| | | |",
                        "| | |#|*| |#|",
                        "| |*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome359() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |#|",
                        "| |#| | | |*|",
                        "|*|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome360() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| |#| | | | | | | |",
                        "| |*| | | | | |#| |",
                        "| |#| |#| | | |#| |",
                        "| |*|*|#| |*| |*|#|",
                        "| |*|#|#| |*| |*|*|",
                        "|*|#|#|#|*|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome361() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | |*| | | |",
                        "| | | |*|*|#| | | |",
                        "| | | |*|#|#| |#| |",
                        "| | | |*|*|*|#|#| |",
                        "|#| | |*|*|#|*|#|#|",
                        "|#|*|#|*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome362() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |*| | | | |",
                        "| | | |#| |#| | |",
                        "|*| |*|#| |*| | |",
                        "|*| |#|*| |#| | |",
                        "|*| |#|#| |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome364() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |#| |#| |#| | |",
                        "| | | | |*|*|#| |*|#| |",
                        "|#|*|*| |*|#|#| |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome365() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| |",
                        "| | | | | | |#| | | |*|*|",
                        "| |#| | | | |#| | |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome366() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|*| | | | | | | | | |",
                        "|#|#| | | | |*|#| |#|",
                        "|*|*| |#| | |*|*|*|#|",
                        "|*|*|*|#|#| |#|#|*|#|",
                        "|*|*|#|*|#|*|#|*|#|*|",
                        "|#|#|*|#|*|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome367() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | |#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome368() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |#| | |*| | | |",
                        "| |#| | |#| | |*| | | |",
                        "| |#| | |#| | |#|*| | |",
                        "|#|*| | |*| | |*|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome369() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |*| | | | | | |",
                        "| | | | |*| | | | | | |",
                        "| | | | |*| |*| | |#| |",
                        "| |*|#|#|*|#|*| |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome370() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | |#| | | | | | |",
                        "|#| | |*| | | |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome371() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| |#| | | | | | | | |",
                        "| |#| | | | | | | | |",
                        "|*|*| | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome372() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome373() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | | |",
                        "| | | | |*| | | | | | | | |",
                        "|*| |*| |*| |*| | | |*|#|#|",
                        "|#| |*| |#| |#| | | |#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome374() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | |",
                        "| | | | |#| | | |#| |*| |",
                        "| |*| |*|#|#| | |*|*|#| |",
                        "|*|#|*|#|#|*| | |*|#|#| |",
                        "|*|#|#|*|#|*|*|#|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome375() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | |#| | | | | |",
                        "|*| | | | | |#| | | | | |",
                        "|*| | | | | |#| |#| | | |",
                        "|#| | | | | |#| |*| | |*|",
                        "|*| | | | |*|#| |*| |#|*|",
                        "|#|#|*|#| |*|*|#|#|*|*|*|",
                        "|*|*|#|#|#|#|*|#|*|*|#|*|",
                        "|#|#|#|*|*|*|#|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome376() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | | | |#| | | | | | | |",
                        "|*| | | | | | |*|*| | | |*| | |",
                        "|*|*| |*| | | |*|#| |#| |#| | |",
                        "|#|#| |*| | | |#|*| |#| |*| | |",
                        "|*|*| |*|*|*| |*|#|#|*|#|#|#| |",
                        "|#|#|*|#|*|*| |#|#|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome377() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "|#| |*|*|#|*|#|#| |#|#| | |#|*|*|",
                        "|*|*|*|#|*|#|#|#|#|#|#|#| |*|*|*|",
                        "|*|#|#|#|#|*|*|*|*|*|#|*| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome378() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | | |",
                        "| | | | | |#| | | |#| | | | |",
                        "|*| | | | |*| | | |*|#| | |*|",
                        "|#|#| | | |#| |*|#|#|*| |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome380() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*|*|#|#| |#|*|*|*|#|*|#|#|*|*| |*|",
                        "|*|*|#|*|#|*|#|*|*|*|*|#|*|#|#| |#|",
                        "|#|*|#|*|#|*|#|#|#|*|*|*|#|#|*|#|#|",
                        "|*|#|#|*|#|*|*|*|#|#|#|#|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome381() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| |*|",
                        "|#| |*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|#|#|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|*|#|*|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome382() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | |#| | | | | | | |",
                        "| | |#| | | | | |*|*|*| | |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome383() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |*|#| |",
                        "| | | |*| | | | | | | | | | |#|#| |",
                        "| | | |*| | | | | | | | | |#|*|*| |",
                        "| |#|*|#| | | | | | | | | |#|#|#| |",
                        "| |*|*|*|#|*| | | | | | |*|#|#|*| |",
                        "| |#|*|#|#|*| |*|*| |*|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome384() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | | |",
                        "| |#| | | | | |*| |*| | | | | | |",
                        "| |*| | | | | |*| |*| |#| | | | |",
                        "| |*| | | | |*|#|#|#| |#|*| | | |",
                        "|#|*|#|*| | |*|*|#|#|#|#|*|#|*|*|",
                        "|#|*|*|#|*|#|#|#|*|#|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome385() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |#| | | | | | |",
                        "| | | | | | | | |*| |*| |*|#|#|#|#|",
                        "| |*|*| |#| | | |#| |#|*|*|#|*|*|*|",
                        "|#|#|#|*|*|#|*|*|#|#|#|*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome386() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "|#| | |*|*| | |*| | | | |#| | |",
                        "|#|*|*|*|*|*|*|#| |#| | |#|*|#|",
                        "|#|#|*|*|*|*|*|#|#|*|#|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome387() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|*|#|#|*|#|#|#|#|*|*|*|*|*|#|*|",
                        "|*|#|*|#|#|#|#|*|#|*|#|*|#|*|*|#|",
                        "|#|*|#|#|*|#|*|*|*|#|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome388() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|",
                        "|*|#|#|*|",
                        "|*|*|*|*|",
                        "|*|#|#|#|",
                        "|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome389() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|*|",
                        "|*|#|#|*|",
                        "|#|#|*|#|",
                        "|*|*|*|#|",
                        "|#|#|#|#|",
                        "|#|#|*|*|",
                        "|#|*|*|#|",
                        "|*|*|*|*|",
                        "|*|#|#|#|",
                        "|*|#|*|#|",
                        "|*|#|*|#|",
                        "|*|#|*|#|",
                        "|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome390() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|#| |*|#| | | | |*| | | |#| | | |#|",
                        "|#| |#|*|*| | | |*| | | |#| | | |#|",
                        "|*| |*|#|*|*| |#|#|*| |#|*| | | |#|",
                        "|#|*|#|*|#|#|*|#|*|*|#|*|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome391() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|*|",
                        "|#|#|#|",
                        "|*|#|*|",
                        "|#|#|*|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|*|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome392() {
        check(GameOutcome.WIN_HASH, 8, new String[]{
                        "| | | | | | |",
                        "| | | | | |#|",
                        "|*|*| | | |#|",
                        "|*|*| | |#|*|",
                        "|*|*| |#|*|#|",
                        "|*|*|#|#|*|*|",
                        "|#|*|#|#|*|#|",
                        "|*|*|#|#|*|*|",
                        "|#|#|*|#|#|#|",
                        "|#|*|#|#|*|#|",
                        "|*|#|*|#|#|#|",
                        "|*|*|#|#|*|*|",
                        "|*|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome393() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|#|*| |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome394() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*|*| | | |",
                        "|#|*| | |#|"
                }
        );
    }

    @Test
    void calculateOutcome395() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|#|*|",
                        "|*|*|#|#|*|",
                        "|#|#|#|*|#|",
                        "|#|#|#|*|*|",
                        "|*|*|*|*|#|",
                        "|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome396() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |#| | | | |",
                        "| | | |#| | | | |",
                        "|*| |*|#|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome397() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |*| |",
                        "|*| | | | | |*| |",
                        "|#| |#| |#| |*| |",
                        "|*| |*|#|#| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome398() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |*| |*| | |",
                        "|#| |#| |#| | |",
                        "|*|#|*| |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome399() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "|#| | | |#|#|*|",
                        "|*| |*| |#|*|*|",
                        "|#| |*| |*|#|#|",
                        "|#| |*|#|#|*|#|",
                        "|#|*|#|#|#|#|#|",
                        "|*|*|*|#|#|#|#|",
                        "|*|#|*|*|*|*|#|",
                        "|*|#|*|#|*|#|#|",
                        "|*|*|*|*|#|#|#|",
                        "|#|*|*|#|#|#|*|",
                        "|#|*|*|*|*|#|*|",
                        "|*|*|#|*|#|*|*|",
                        "|*|*|#|*|#|*|#|",
                        "|*|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome400() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | |#| | | |#|",
                        "| | | |*| | | |#|",
                        "| | |*|*| | |*|#|",
                        "|#|#|*|#| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome401() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| |*| | | | | | |",
                        "| |#| | | | | | |",
                        "| |*| | | | |#| |",
                        "| |*| | | | |#| |",
                        "| |#| |*| |*|#| |",
                        "|*|*| |#|#|#|*| |",
                        "|#|#| |*|*|#|*| |",
                        "|#|*|*|*|#|#|*|#|",
                        "|*|#|*|*|*|#|*|#|",
                        "|#|#|#|*|#|#|#|*|",
                        "|#|#|*|#|*|*|*|#|",
                        "|*|*|*|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome402() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |#|",
                        "|#| | | | |#|",
                        "|*| | |#|#|*|",
                        "|#| | |*|*|*|",
                        "|*| | |*|#|*|",
                        "|#| |*|#|#|#|",
                        "|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome403() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*|*|#| |*|*| |",
                        "|#|*|#|#|*|#|#|",
                        "|#|#|#|#|*|*|*|",
                        "|#|*|*|#|#|*|*|",
                        "|#|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome404() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | |#|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome405() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | |*| | | |",
                        "| | | |#| | |*| | | |",
                        "| | | |*| | |#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome406() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*|*|#|#|#| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome407() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |*| | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome408() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| |",
                        "| | | | |*|#| | |#| |*|*|",
                        "| |*|*| |*|#| | |*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome409() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | |*| |#| | | |#| | | |",
                        "|*| |#| |*|*| | |*| | | |",
                        "|#| |#| |#|*|#| |*|*| | |",
                        "|*| |*|#|*|#|#|#|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome410() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | |#| | | | |",
                        "| | | | | | |*| | | | |",
                        "| |*|#|#|*| |*| |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome412() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | |",
                        "|*| | |#| | | | | | | | | | |",
                        "|*| | |*| |#| | | | | | | | |",
                        "|#| |#|#| |#| | | | | | |*|#|",
                        "|#| |#|#| |#|*| | |*| | |*|*|",
                        "|*| |#|#| |#|*| | |#|#| |#|*|",
                        "|*|*|*|#| |#|#| |*|*|#|*|*|*|",
                        "|*|*|#|*|*|*|#| |*|*|*|#|#|#|",
                        "|#|*|#|#|*|#|*|#|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome413() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | |*| |",
                        "| | | |#| | |*| |*|*| | | |#|*|",
                        "|*| | |#|#| |#|*|#|#| |#| |#|*|",
                        "|*| | |#|#| |*|*|#|#| |#|#|*|#|",
                        "|*|#|*|#|*| |*|*|#|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome414() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |*| |",
                        "|*| | | |#| | | | | | |#| |",
                        "|*| | | |#| | |#| | | |#| |",
                        "|#| |#|*|*| |*|*|#|*| |*|#|",
                        "|*|#|*|#|*|*|*|#|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome415() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | | |",
                        "| | | | | | | | | |*| | | | |",
                        "| | | | | |*| |#| |*| |#| | |",
                        "| | |#|#|#|*| |#|*|*|#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome416() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| |#| | |",
                        "| |#| | |",
                        "|*|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome418() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome419() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|#|#|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome420() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |*| | | | |",
                        "|#|*| |#| |*|",
                        "|#|*| |#| |*|",
                        "|*|*| |#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome422() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|#| | | | |",
                        "|*| | | |*|",
                        "|*| |*| |#|",
                        "|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome423() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | |*| | | |",
                        "|#|#|#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome424() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | |*| | | |",
                        "| | | | |*| | | |",
                        "| | | | |#| | | |",
                        "| | | | |#| | | |",
                        "| | | | |*|*| | |",
                        "| |*| | |*|#| | |",
                        "| |*| | |#|#| | |",
                        "| |#|#|*|#|*| | |",
                        "|*|#|#|*|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome425() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|#| | | |#|*|*| |#|",
                        "|#| | | |*|*|*| |*|",
                        "|#|*|#|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome426() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |*| | | |",
                        "|#| | |#| | | |",
                        "|#| |#|*|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome427() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |#| | | | | | |",
                        "| |*| | | | | | |",
                        "| |*| | |#| | | |",
                        "| |#| | |#|*|*|#|",
                        "|*|*| |#|*|*|#|#|",
                        "|#|#| |#|*|#|*|#|",
                        "|#|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome428() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |*| | | | |#| |",
                        "| |#| | |#| | | | |*| |",
                        "| |*| | |#| |#|#|*|#| |",
                        "| |*| | |*| |*|#|*|*| |",
                        "| |#| | |#|#|#|#|*|*| |",
                        "| |*| | |*|*|*|#|*|*| |",
                        "|#|#|#|#|#|#|*|*|#|*| |",
                        "|*|#|*|#|#|*|#|*|#|#|*|",
                        "|*|*|*|#|*|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome429() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|*|*|#|*|#|#|*|#|#|",
                        "|*|*|#|#|#|#|*|*|#|*|*|",
                        "|#|#|#|*|#|*|#|*|*|*|*|",
                        "|*|#|*|*|#|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome430() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*| | | |#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome431() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|*|*|#|*|#|#|#|*|",
                        "|#|#|#|*|#|#|*|#|*|*|",
                        "|*|*|*|*|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome432() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| |#| | | | | | | |#|",
                        "| |*|*|#| | | | |*|*|",
                        "|#|*|#|#|*|*| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome433() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | |*| | | | | | |#|",
                        "|*| | |#|#|#| | |*|*|#|",
                        "|*|*|*|*|#|#|#| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome434() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | |*|*| | | |",
                        "|*|*|#|#|#|#| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome435() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|#| | | | | |*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome438() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | |*| | | | | | | |",
                        "| |#| |#| | | |*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome439() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | |",
                        "| | | | | | | |#| | | | |",
                        "| | | |#| | | |#| | | |*|",
                        "|#|*| |*|#|*| |#| | |#|*|",
                        "|*|*| |*|*|*|#|*|*|#|*|*|",
                        "|#|*|#|*|#|#|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome440() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|*|*|*|#|*|#|*|*|#|*|*|*|",
                        "|#|#|#|#|*|#|#|#|#|#|*|#|*|*|*|",
                        "|#|*|*|*|#|*|#|*|#|*|#|#|*|#|#|",
                        "|*|#|#|#|#|*|*|#|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome441() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|*|#|*|#|*|*|*|*|*|#|*|#|",
                        "|#|#|#|#|#|*|*|#|*|*|#|*|*|#|*|",
                        "|*|#|#|#|*|#|*|#|#|#|#|#|#|*|*|",
                        "|*|*|*|*|#|#|*|#|*|#|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome442() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "|*| | | | | | | | |#| | | |",
                        "|*|*| | | |*| |#|#|#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome443() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | |#| |*| | |*| |*| | | |",
                        "|*| |*|#| |#| | |#|#|*|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome444() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | |#|*| | | |*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome445() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |*| | | | |",
                        "| | | |*| | | | | | | |*|*|*| | | |",
                        "|#|*| |#| | |#| | |#|#|#|#|*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome446() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| | | |#| |",
                        "|*| | | | | | |#| | |*| |*| |*| |",
                        "|#| |#|*| |#| |#| | |#| |*|#|*|#|",
                        "|*|*|#|*|*|#| |*| | |*| |#|*|*|*|",
                        "|*|#|*|#|#|#| |*|*| |*| |*|#|*|*|",
                        "|#|#|*|*|#|*|#|*|#|#|#|#|#|#|*|#|",
                        "|*|*|*|*|#|*|#|#|#|*|#|#|#|#|#|*|",
                        "|#|#|#|*|*|*|#|#|#|*|*|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome447() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#| | | | |",
                        "|*| | | | | | | | | | |*| | |*| |",
                        "|#| | | | | |#| | | |*|*|#| |#| |",
                        "|*|#| | |#| |*|*| |*|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome449() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | |#| | | |",
                        "| | | |*| | | |",
                        "| | | |*| | | |",
                        "| | | |#| | | |",
                        "|*| | |#| | | |",
                        "|*| | |*|*| | |",
                        "|#|#| |*|*|#| |",
                        "|*|*|#|#|#|#|#|",
                        "|#|#|*|#|*|*|*|",
                        "|*|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome450() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|#|*|",
                        "|*|*|#|#|*|",
                        "|#|#|*|*|#|",
                        "|*|*|#|*|#|",
                        "|#|#|#|*|*|",
                        "|*|#|*|*|*|",
                        "|*|#|#|#|*|",
                        "|#|*|#|*|#|",
                        "|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome451() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | |#| | |",
                        "|#| | |*| | |",
                        "|*|#|*|*|*|#|",
                        "|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome452() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#| |*| | | | |",
                        "|*| |#| |*| | |#| |",
                        "|#|#|#| |#|*| |*| |",
                        "|*|*|*|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome453() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome454() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|*|#|*|#|*|#|",
                        "|#|*|#|*|#|#|*|#|",
                        "|*|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome455() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |*|#| | | |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome457() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|*|#|*|*|#|*|*|*|",
                        "|*|#|*|#|#|#|*|#|#|#|*|",
                        "|*|#|#|#|*|*|#|*|*|#|#|",
                        "|#|*|#|#|#|*|#|#|*|*|*|",
                        "|#|#|*|#|#|#|*|#|*|*|#|",
                        "|*|#|#|#|*|*|*|*|#|#|*|",
                        "|#|*|*|*|#|#|#|*|#|*|#|",
                        "|#|#|#|*|*|#|#|*|*|*|*|",
                        "|*|#|#|*|*|*|#|#|*|*|#|",
                        "|#|*|*|#|*|*|#|*|#|*|#|",
                        "|*|#|*|#|#|*|#|#|#|#|*|",
                        "|*|*|#|*|#|*|#|#|#|*|*|",
                        "|#|#|*|#|*|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome458() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|*| | | | | |#| | | |",
                        "|#| | | | |*|#|*|*| |",
                        "|#| |*|#|#|*|*|#|#|#|",
                        "|*|*|*|*|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome459() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|#| | | | | |*|*|#| |",
                        "|*| | | | |#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome460() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome461() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | | | |",
                        "|#| | | |#|*| | | |*| | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome462() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|#| | | | | | |#|#|#| | |",
                        "|*| |*| |*|*|#|*|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome463() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | |#|",
                        "|#| | | | | |*| | | | |#|#|",
                        "|#|*| |*|#| |#| | | |*|#|#|",
                        "|#|*| |#|*| |#|*| | |*|*|*|",
                        "|*|*| |*|*| |#|#| |*|#|*|#|",
                        "|#|#|#|*|*|#|*|#| |*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome464() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | |#|#| | | | | | | | | |",
                        "| |#|#|#| | | | | |*| | | |",
                        "| |*|#|*| |*| | | |#| | | |",
                        "|*|#|#|*|*|*| |#|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome465() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|#|#|*|*|#|#|*|*|#|#|",
                        "|#|*|#|*|*|#|#|#|*|#|#|*|*|",
                        "|#|#|*|#|#|#|*|#|*|*|#|#|*|",
                        "|#|*|#|*|#|*|*|*|#|#|#|*|*|",
                        "|#|#|*|#|*|*|#|#|*|#|#|*|*|",
                        "|#|#|#|#|*|*|#|*|#|*|*|*|#|",
                        "|*|#|*|*|#|*|#|*|#|#|#|*|#|",
                        "|*|#|#|*|*|#|*|*|*|#|*|#|#|",
                        "|*|*|*|*|*|*|*|#|*|*|#|*|*|",
                        "|#|*|#|#|*|*|*|#|*|*|*|#|#|",
                        "|#|*|*|#|*|#|#|*|*|#|#|#|*|",
                        "|*|*|*|#|*|*|*|*|#|*|#|#|*|",
                        "|#|#|#|#|*|#|#|#|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome466() {
        check(GameOutcome.WIN_HASH, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | |",
                        "|*| | | | | | |#| | | |*|",
                        "|*|#| | | | |#|#| | |#|*|",
                        "|*|*| | | | |*|#| | |*|#|",
                        "|*|#| | | | |#|#|#| |#|*|",
                        "|#|*| |*| | |#|#|#|*|*|#|",
                        "|*|#|#|*|*|#|*|#|*|*|*|*|",
                        "|#|*|*|#|#|*|*|#|*|#|*|#|",
                        "|#|*|*|*|#|*|#|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome467() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#|",
                        "| | | | | | | | | |*| |*|",
                        "| | | | | |*| | | |#| |#|",
                        "|#| | | |*|*|*|#| |#| |*|",
                        "|#| | |#|#|*|*|#| |#|#|#|",
                        "|*|*|#|*|*|*|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome468() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | | |",
                        "|#|#| | |*| | | |*| | | | | |*|",
                        "|#|#| | |*| | |*|*|#| | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome469() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |#| | | | | |*| | |",
                        "| | |*| | | |*| | | | | |#| | |",
                        "| | |#| | | |#| | | | | |*| | |",
                        "| |#|#| | |#|#| |*| |*| |#| | |",
                        "|*|#|*|#|*|*|#| |*|#|*| |*| |#|",
                        "|*|*|#|#|*|#|*|#|*|*|*| |*|#|#|",
                        "|#|#|#|#|*|#|#|*|*|*|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome470() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | | |",
                        "| | |*| |*| |*|#| | | |#|#| |",
                        "| | |*|*|#| |#|#| |*|*|*|#| |",
                        "|#| |#|#|*| |#|*|*|#|#|#|*| |",
                        "|#|*|*|#|#| |*|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome471() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | |",
                        "| | |*| | | | | | | |*|*| |#|",
                        "| |#|*| | | | | |*| |*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome473() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|*| | |",
                        "|*| | |",
                        "|*| |#|",
                        "|#| |#|",
                        "|*|*|#|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome474() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | | | | |",
                        "|#| |#| |*|#| |*|*| | | | | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome475() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| |*| |#| | | | | | | | | | |#| | |",
                        "|*|*| |#|*| | | | | | | |*|#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome476() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | |#| |",
                        "| | |#| |",
                        "| | |#| |",
                        "| |#|#| |",
                        "| |#|*| |",
                        "| |*|#|*|",
                        "| |*|*|*|",
                        "|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome477() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*| | | | |",
                        "|#| | | | |",
                        "|*| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome478() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| |*| |",
                        "| |#| |",
                        "| |#|#|",
                        "| |#|*|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|*|*|#|",
                        "|*|#|*|",
                        "|*|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome479() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | |#|",
                        "| | | |#|",
                        "| | | |#|",
                        "|*| | |*|",
                        "|*|#|#|#|",
                        "|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome480() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|#| | |#| | | |*|*|",
                        "|*|*| |*|#|#| |#|*|",
                        "|#|#| |*|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome481() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | |*| | | |",
                        "|#| |*|#| | |#| |*| |",
                        "|#|*|*|*|#| |*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome482() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |*| | | | | |",
                        "| | |#| | | | | |",
                        "|*| |#| | |#| | |",
                        "|*| |*| |*|#| |#|",
                        "|#|*|*|#|*|*|#|*|",
                        "|#|#|#|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome483() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | |*| | |",
                        "| |#| |*| | |#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome484() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| |#| |*| | | | | | | |",
                        "|*|*|*|#|#| | | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome485() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|*| | | | | | |#| | | | |",
                        "|*|*|#|#|#|#| |*|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome486() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |*|#| |*| | |",
                        "| |*|#|#|#|#| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome487() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | |#|",
                        "|*| | | |#| |*| | | |#|",
                        "|#| | | |*| |*| |#| |*|",
                        "|#|*|*| |#|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome488() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| |",
                        "| | | | | | | | | | | | |#| |",
                        "|#|*| | | | | | | | | |*|*| |",
                        "|*|*| | |*| | | | |#|*|*|*| |",
                        "|*|#|*|#|#| |#|#|#|#|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome489() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | |",
                        "| | |*| | | | | | | | |#| | |",
                        "| |*|*| | | | | | |*| |*| | |",
                        "| |#|*| | | | |*| |#| |*| | |",
                        "| |*|#| | |#| |#| |*| |#| | |",
                        "| |#|*| | |#| |*| |#| |*| | |",
                        "| |#|#|#|#|*| |*|*|*|#|#|*| |",
                        "|*|*|#|#|*|#|#|*|*|#|#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome490() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | |",
                        "| |#| | |*| | |*| | | | |",
                        "| |#| | |*| |*|#| | | | |",
                        "| |#|*| |#| |*|*| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome491() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "|*| | | | |*| | | | | | |#|",
                        "|*| | | | |*|*| | | | |#|#|",
                        "|#| | | | |*|#| | | |*|#|*|",
                        "|#| | | | |#|*| | |*|#|*|#|",
                        "|*|*| |#| |*|*| | |#|#|*|*|",
                        "|#|*|#|*| |#|#|*| |#|#|#|#|",
                        "|*|#|#|#|*|#|*|*|*|*|*|#|*|",
                        "|#|*|#|*|#|*|#|*|#|#|#|*|*|",
                        "|#|#|#|*|*|#|*|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome492() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | |*| | | | | | | | |*|",
                        "| | | | |#|*|#| | |*| | |#| |#|#|",
                        "|*| | |#|#|#|*|*|#|#| |*|#|#|*|#|",
                        "|#|#|*|*|#|*|*|*|*|*| |*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome493() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|#|#|*|*|#|*|*|#|*|#|*|*|*|",
                        "|#|#|#|*|#|#|#|#|#|*|#|*|*|#|*|*|",
                        "|#|*|#|#|#|#|*|*|#|*|*|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome494() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | | |",
                        "| | |#| | | | | |#| | |#| | | |",
                        "| | |#| | | | | |*|*| |#|*|#|#|",
                        "| | |#|*|*|*| |*|#|#| |*|#|*|*|",
                        "|*| |#|*|*|#| |#|*|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome495() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | |#|*| | | | | | | | | | | |",
                        "| | |#|*| | | | | | | | | | | |",
                        "|*| |*|#| | | | | |*| | | | | |",
                        "|#| |#|*|*| | |#| |#| | | | | |",
                        "|*|#|*|*|#|#| |#| |*|#| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome496() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| | |",
                        "| | | | | | | | | | | | |#| | |",
                        "| | | | | | | | | | | | |#| |#|",
                        "| | | | | | | | | | | | |*| |*|",
                        "| | | | | | | |#| | | | |#| |#|",
                        "|*| | | | |*|#|*| | | | |*|#|#|",
                        "|*| |#|#|#|*|*|*|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome497() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |#| | | |#| |*| | | | |#|*|",
                        "|*| | |*|*| |#|*| |#| | | | |#|*|",
                        "|*| |#|*|#| |*|#| |#| | |*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome498() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | |#| | | |",
                        "| |*| | | | | | | | |*| | | |",
                        "|#|#| | | | |*| | |#|*| | | |",
                        "|#|*|*| |#|#|*|*| |*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome499() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "| | | | | | | |*| | | |*| | | |",
                        "| |#| | | | |#|#| | | |*|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome500() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|#|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|*|*|*|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|#|#|*|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome501() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| |#|#|",
                        "| |#|*|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|*|*|*|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome502() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | | |",
                        "| | | |*| | |#|#| | | | | | | | |",
                        "| | |*|#| |#|#|#|*| | |*|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome503() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |#|",
                        "| | | | | | | | | | | | | | | | |#|",
                        "| | | | |*| | | | | | |#|*|#| | |#|",
                        "|*|#| | |*| |*| | |*| |*|#|#| | |#|",
                        "|#|#| |*|*| |#| | |#|*|#|#|*| |*|#|",
                        "|*|#|*|#|#|*|*| |#|*|*|#|*|*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome504() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome505() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|*|*|",
                        "|*|#|*|#|*|",
                        "|*|*|#|*|#|",
                        "|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome506() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |",
                        "| | |#| |",
                        "|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome507() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|*|",
                        "|#|*|*|*|",
                        "|*|*|#|*|",
                        "|#|#|*|#|",
                        "|*|*|*|#|",
                        "|#|*|#|#|",
                        "|#|#|#|*|",
                        "|*|*|#|*|",
                        "|#|#|*|#|",
                        "|*|*|#|#|",
                        "|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome508() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|*|*|#|#|*|",
                        "|#|#|#|*|#|*|#|",
                        "|*|*|#|*|#|#|*|",
                        "|#|*|*|*|#|#|#|",
                        "|*|#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome509() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |*|#| | | |",
                        "| | |#|#| |#|*|",
                        "|*| |*|#| |#|*|",
                        "|#|#|*|*| |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome510() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | |*| |",
                        "|#|*| | |#| |",
                        "|#|*| | |*| |",
                        "|#|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome511() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | |#| | | |",
                        "| | |#| | | |",
                        "| | |#| | | |",
                        "| | |*| | | |",
                        "|*|#|#|*| |#|",
                        "|*|#|*|#|*|#|",
                        "|*|*|*|#|*|*|",
                        "|*|#|*|#|#|#|",
                        "|*|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome512() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |*|#| | | | | | | |#| |*|",
                        "| | |*|*|#| |#| | |#| |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome513() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | | |*| |",
                        "| | | | | | | | | |#|*|*| |*| |",
                        "| | | | |*| | | | |#|*|#| |*| |",
                        "|#| | |#|*|*|#| | |#|*|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome514() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | |*|",
                        "|*| | |#| |*| |*|*|#|#| |*|",
                        "|*|*|#|#| |#| |*|*|#|#| |#|",
                        "|#|#|#|*| |*|*|#|*|*|*|*|#|",
                        "|*|*|#|#| |#|#|*|#|#|#|*|*|",
                        "|*|*|#|#| |*|#|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome515() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | |",
                        "| |#|#|#| | | | | | | | | |*|",
                        "|*|#|#|*|*| |*| |*| | | |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome516() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#| | | | |",
                        "| | | | | | | | | | | |#| | | | |",
                        "| | | | | | | | | | |*|#| | | | |",
                        "| | |*| |*| | |*|*| |#|#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome517() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome518() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |#|",
                        "| | | |#| |*| | | | | | | | |*|",
                        "| |#| |*| |#| |#| |*| | |#|*|*|",
                        "|*|#|#|*| |#|*|*|*|#|#| |#|*|*|",
                        "|#|#|#|#|*|#|*|*|#|#|*| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome519() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | |*| | | |",
                        "| |*|*| |*| | | | | | | |#| | | |",
                        "| |#|*| |#|#|*|*|*|#|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome520() {
        check(GameOutcome.TIE, 4, new String[]{
                        "|*|#|*|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|*|#|",
                        "|*|*|*|",
                        "|#|#|*|",
                        "|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome521() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|*|#|*|#|",
                        "|#|*|*|*|",
                        "|#|#|*|#|",
                        "|#|*|#|*|",
                        "|#|*|*|#|",
                        "|*|#|#|#|",
                        "|#|*|*|*|",
                        "|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome522() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | | | | | |",
                        "| | | |#| |*| | | | | | | | | | | |",
                        "| | | |#| |#| | | | | | | | | | | |",
                        "|*|#|#|*| |*| |*|*| |*| | | | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome523() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "|#| | |",
                        "|*| | |",
                        "|#| | |",
                        "|*| | |",
                        "|*| | |",
                        "|#|#|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome524() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | |#| | | |",
                        "| | |*| |#| |",
                        "| | |#| |*| |",
                        "| |*|*| |#| |",
                        "|*|#|#| |#|#|",
                        "|#|*|*|*|*|#|",
                        "|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome525() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | |*| |",
                        "| | | | |#| |",
                        "| | | | |#| |",
                        "| | |#| |#| |",
                        "|*| |*| |#|#|",
                        "|*| |*| |*|*|",
                        "|*| |#| |#|#|",
                        "|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome526() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|*|*|#|*|#|",
                        "|#|#|#|*|*|",
                        "|*|*|#|#|#|",
                        "|#|*|*|#|*|",
                        "|#|*|#|*|#|",
                        "|*|#|#|*|*|",
                        "|*|#|#|#|*|",
                        "|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome527() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*| | |#| |",
                        "|#|*| |#| |",
                        "|#|#|#|*| |",
                        "|*|*|*|#|#|",
                        "|#|*|*|*|#|",
                        "|*|*|*|*|#|",
                        "|*|#|*|#|*|",
                        "|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome528() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | |",
                        "|*| | | | |",
                        "|*| |#| | |",
                        "|*| |*| | |",
                        "|#| |#| | |",
                        "|#|#|*|*|#|",
                        "|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome529() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | |*| | |",
                        "| | |*|#| |#|",
                        "| | |#|*| |#|",
                        "| |*|*|#|#|*|",
                        "|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome530() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome531() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| |*| | | |",
                        "| |#| | | |",
                        "| |#| | | |",
                        "| |*| |*| |",
                        "| |*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome532() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | |#|",
                        "| | | |*| | |*|",
                        "|#| |*|#| | |#|",
                        "|#|#|*|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome533() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |#| | |#| |",
                        "| |#|*|*|*|*|#| |",
                        "|#|#|*|*|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome534() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|*|#|#|*|*|#|",
                        "|*|*|#|*|*|*|",
                        "|#|*|#|*|#|*|",
                        "|*|*|#|#|#|#|",
                        "|#|#|*|#|*|#|",
                        "|#|#|#|*|#|*|",
                        "|#|*|*|*|#|*|",
                        "|#|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome535() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | |*|*| |",
                        "| |#| |*|*|#| |",
                        "|#|#| |*|#|*|*|",
                        "|#|#|#|#|*|#|#|",
                        "|*|#|*|*|*|#|*|",
                        "|#|*|#|*|*|#|*|",
                        "|#|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome536() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|*| |#| | | | | | | |",
                        "|*| |#|*|*|*| | |#| |",
                        "|*| |#|*|*|#| |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome537() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| | | | | | | | | |",
                        "|#|*| | | | | | | | |",
                        "|*|#| | | | | |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome538() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | |*| | |",
                        "| | | | | | |*| |#|",
                        "| | | | | | |#| |*|",
                        "| | | | | | |#| |#|",
                        "| | |*| |#| |*|*|*|",
                        "| | |#|#|#|#|#|*|*|",
                        "| | |*|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome539() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | |#|",
                        "| | | | | | | | |*|",
                        "|*| | | | | | | |*|",
                        "|#| | | | | | | |#|",
                        "|#|*| |#| | |#| |*|",
                        "|#|#| |#| | |#| |#|",
                        "|*|*| |*| | |*| |*|",
                        "|#|*|#|*| | |#| |*|",
                        "|#|#|#|*|*| |*| |#|",
                        "|*|#|#|*|#| |#|*|*|",
                        "|*|*|#|#|*| |#|#|*|",
                        "|#|#|*|*|*|*|*|*|#|",
                        "|*|#|*|#|*|*|#|*|#|",
                        "|#|*|*|*|*|#|#|#|*|",
                        "|*|#|#|#|#|#|*|#|#|",
                        "|*|*|#|*|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome540() {
        check(GameOutcome.WIN_STAR, 7, new String[]{
                        "| | | | | | | | |*| | |*|",
                        "| | | | |#| | | |#|#| |*|",
                        "|#| |#|*|*| | |#|#|#|#|#|",
                        "|*|#|*|*|*|*|*|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome541() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | |#| |#|#|",
                        "|#| | |#|*| |*| |*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome542() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| |*| | | | | | | | | |",
                        "| |#| | | | | | | |*| |",
                        "| |*|#|#| | | | | |*| |",
                        "| |*|*|#| | | |*| |*| |",
                        "| |*|#|#|#|#|#|#| |#| |",
                        "|*|*|*|*|#|#|#|*|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome543() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |#| |*| | | | |*| |",
                        "| | |#| |#| | | | |#| |",
                        "| | |#| |#|#| | | |#|*|",
                        "| | |#| |*|#| | |#|*|*|",
                        "|*|*|#| |#|#|*|#|*|*|*|",
                        "|*|*|#|*|*|#|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome544() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | |*| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome545() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |*|#| | | | | | |",
                        "| | | | | | | | | |#|#| | | | | | |",
                        "| | | |*| | | | | |#|#| | | | | | |",
                        "| |*| |#| | | | | |*|*| | |#| |*|#|",
                        "|#|*|*|#|#| |*|*|*|#|*| |#|*|#|*|*|",
                        "|*|*|#|#|*| |#|*|#|#|#|#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome546() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | | | | | |",
                        "| |*| |*| | | | | | | | | | | | |",
                        "| |*|*|*|#| | | | | | | |#| | | |",
                        "|#|*|#|#|*| | |*| |#| | |#| | | |",
                        "|#|*|#|*|#| |*|*| |#|*| |#|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome547() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |*|*| | | | | | | |#| | | |#| |",
                        "| |#|*| | |#| | | | |#| | | |*| |",
                        "| |#|#| | |*| | | | |#| | |#|*| |",
                        "| |#|*| | |#|*|*|*|*|*|*|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome548() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| | | |",
                        "|#| | | |",
                        "|#|*|#|*|",
                        "|#|*|#|*|",
                        "|#|*|*|#|",
                        "|*|*|#|*|",
                        "|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome549() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |",
                        "| | |*| |",
                        "| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome550() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|*|#|",
                        "|#|*|#|",
                        "|#|#|#|",
                        "|*|#|#|",
                        "|*|*|*|",
                        "|*|#|*|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome551() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|",
                        "|#|*|*|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|#|*|#|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome552() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|#|*|#|#|",
                        "|#|*|*|#|#|*|",
                        "|*|*|*|#|*|#|",
                        "|*|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome553() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|#| | | |#| | |",
                        "|*|#|*| |*| | |",
                        "|#|*|#|*|#|*| |",
                        "|#|*|*|#|#|*| |",
                        "|*|#|#|#|*|#| |",
                        "|*|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome554() {
        check(GameOutcome.WIN_STAR, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |#|",
                        "|*| | |#|#|",
                        "|*| | |#|*|",
                        "|*| | |#|*|",
                        "|*|#|*|*|#|",
                        "|*|*|#|#|#|",
                        "|*|#|#|*|#|",
                        "|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome555() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*|*| |*|*| |",
                        "|#|*| |#|#|#|",
                        "|#|*| |#|#|*|",
                        "|*|#| |#|*|#|",
                        "|#|#|#|*|*|*|",
                        "|*|#|*|#|#|#|",
                        "|*|#|#|*|*|*|",
                        "|*|#|*|#|#|*|",
                        "|#|*|#|*|*|*|",
                        "|#|#|#|*|*|#|",
                        "|#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome556() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |*| |",
                        "| | | |#| |#|#| |",
                        "| |*|*|#| |*|#| |",
                        "| |*|#|#|*|#|*| |",
                        "| |*|*|#|#|#|*|*|",
                        "|*|#|#|#|*|#|*|#|",
                        "|#|*|*|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome557() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |#| | | | |#|",
                        "| | | |#|#| | | |*|",
                        "|*|#|*|*|#| |*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome558() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | |*| |*|",
                        "| | | |#|*| |#|",
                        "| | | |*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome559() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |*|#|",
                        "| | | | | | |#|#|",
                        "|*| | |#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome560() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|#|#|*|#|#|",
                        "|*|*|*|#|*|*|#|*|",
                        "|#|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome561() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|*|*|*|#|*|",
                        "|#|#|*|#|#|#|*|*|",
                        "|*|*|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome563() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "|#|*| |#|#|*| |",
                        "|*|#| |#|*|#|#|",
                        "|*|*|*|*|*|*|#|",
                        "|*|#|*|#|#|*|*|",
                        "|#|*|#|#|#|#|*|",
                        "|#|#|#|*|*|*|*|",
                        "|#|#|*|#|#|*|*|",
                        "|*|#|*|#|#|#|#|",
                        "|*|*|*|*|*|#|*|",
                        "|#|*|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome564() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |*|#| | | | |",
                        "|*| |#| |*|*|*|#| | |",
                        "|#|#|*| |*|#|#|#| |*|",
                        "|#|*|#| |*|#|#|#|*|*|",
                        "|*|*|*|#|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome565() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|#| | | | | | | | | | |",
                        "|*| | | | | | | | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome566() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | |*|",
                        "| | | |#| | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome567() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| |#| | | | | | | | |",
                        "| |*| | | |*| | | | |",
                        "| |#| | | |*| |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome568() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | |*| | | | |",
                        "| | | | | | | |*| | | | |",
                        "| | | | | | | |#| | | | |",
                        "| |#| | | | | |#| | | | |",
                        "| |#| | | | | |*| |*| | |",
                        "| |#| | | | | |#| |#|#| |",
                        "| |*| |#|*| | |#|*|#|*|#|",
                        "| |#| |#|*| |*|*|*|#|#|*|",
                        "|*|*|*|*|*|#|*|#|*|#|*|*|",
                        "|#|#|*|#|*|*|#|*|#|#|*|#|",
                        "|*|*|#|*|#|#|#|#|*|*|*|#|",
                        "|#|*|*|*|#|#|#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome570() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|#| | | |#| | | | | | |",
                        "|#| |#|*|*| | | | |#| |",
                        "|#|#|*|*|#| |*| |*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome571() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | |",
                        "|*| | |*| | | | | | | | |",
                        "|#| | |*| |*| | |#|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome572() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome573() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |",
                        "|#|*| | |#| | | | | |*| | | | |",
                        "|*|#| | |*| |#| | | |#| |*| |#|",
                        "|#|*| | |#| |*|*| |#|*|*|*| |*|",
                        "|#|*|*|#|#|*|*|#|#|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome574() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |*|",
                        "| | | | | | |#|#|#| |*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome575() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | | |",
                        "| | | | | | |#| | | | | | | |",
                        "| | | | | | |*| | | | | | | |",
                        "| | |*| | | |*| |#|#| |*| | |",
                        "|#| |*|#|#| |#|*|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome576() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | | |",
                        "|#|*| | |",
                        "|*|*| | |",
                        "|*|#| | |",
                        "|#|*| | |",
                        "|*|#|#|#|",
                        "|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome577() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| |#| | | |",
                        "| |#| | |*|",
                        "| |*|*|#|#|",
                        "|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome578() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |"
                }
        );
    }

    @Test
    void calculateOutcome579() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| |*|*| |",
                        "|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome580() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |*| | | |*|",
                        "| |#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome581() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome582() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |*|",
                        "| | | | |#|",
                        "|*| |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome583() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|#|#|#|*|",
                        "|#|#|*|#|#|#|",
                        "|*|#|#|*|#|#|",
                        "|*|*|*|#|*|#|",
                        "|*|*|#|*|*|#|",
                        "|*|#|#|*|*|#|",
                        "|#|*|*|#|#|*|",
                        "|*|*|#|*|*|*|",
                        "|*|#|#|#|*|*|",
                        "|#|*|*|*|#|*|",
                        "|*|#|#|#|#|*|",
                        "|#|#|#|*|*|#|",
                        "|*|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome584() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |#| |",
                        "| | | | |*| | |#| |",
                        "|#| |*| |#| |*|#| |",
                        "|#|*|#|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome585() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | |#|#| |",
                        "| |#| | | | |*|*| |",
                        "|*|#|*|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome586() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "|*| | | | | | | |",
                        "|*| | |#|*| | | |",
                        "|#|#|#|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome588() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |#| |*|*| | |"
                }
        );
    }

    @Test
    void calculateOutcome589() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| |*| | | | | | | | | |",
                        "| |*| | | | | |*| | | |",
                        "|#|*|*| | |#|#|#| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome590() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | |*|",
                        "| | | | | | | | | |#|",
                        "| | | | | | | | | |*|",
                        "| | | | | | | | | |*|",
                        "|#| | | |#| | |*|*|#|",
                        "|*| |#| |*| |#|#|*|*|",
                        "|#| |*|#|#|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome591() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | |#| | | | | | | |",
                        "| | |*| | | | | | | |",
                        "| | |#| | | | | | | |",
                        "| | |*| | | | |#| | |",
                        "| | |#| | | | |*| | |",
                        "| | |#| | | | |#| | |",
                        "| | |*| |#| | |#| | |",
                        "| | |#|*|#| | |*| | |",
                        "| |*|*|*|#| | |*|*|#|",
                        "| |*|#|#|#| |*|#|#|*|",
                        "|#|*|#|#|*|*|*|*|*|*|",
                        "|*|*|*|#|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome592() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| |#| |*| | | | | | |",
                        "| |#| |#| | | | |#| |",
                        "| |#| |*| | | | |#| |",
                        "|*|*| |*| | | | |*|*|",
                        "|#|#| |#|*|#| |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome593() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | |#| | | |",
                        "| | | | |*|*| |#|*| |#|",
                        "| | | |#|#|#| |*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome594() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |#| | | | | |",
                        "| | | |#| |*| | | |",
                        "|#|*| |*| |*|*| | |",
                        "|#|#| |#|#|*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome595() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | |#| | | | | | | |",
                        "| | |*|#| |*|*| | | |",
                        "| |*|#|*| |#|#| | |#|",
                        "| |#|*|*|#|*|*|#|*|#|",
                        "|#|#|#|*|*|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome596() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | |",
                        "|*|*| | | | | | | | | | | |",
                        "|*|*| | | | | | | | | | |*|",
                        "|#|#|*| |*|#| | | | | | |*|",
                        "|#|*|#| |#|#|#| | |#| |*|*|",
                        "|*|*|#|#|#|*|*|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome597() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | |",
                        "| | | | |#| | | | | | | | |",
                        "|#| | | |*| | |#| | | |#| |",
                        "|*| |*| |*|#|*|#|#|*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome598() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| |#| | | | | | | | |*| |",
                        "| |*|#|*| |#|*| | |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome599() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#|",
                        "| |*| | | | |*|*|#| | |#|",
                        "|*|#|*| |*| |#|#|#|*|*|#|",
                        "|*|#|*|#|#|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome600() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | |*| | | | |#| |#| | | |*|"
                }
        );
    }

    @Test
    void calculateOutcome601() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|*| | |*| | | | | | | | | | | |",
                        "|#| |#|*| |#|*| |#|#|*| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome602() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | |",
                        "|#| |*|#| | | | |*| | | | | |",
                        "|#| |#|#| |*| |#|#|#|#|#| | |",
                        "|*|*|#|*|*|*| |*|*|*|#|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome603() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome604() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|#|#| |#|#| |#|#|#|#|#| |*| |*| | |",
                        "|*|*|*|#|*| |#|#|#|*|*|*|#| |*|*| |",
                        "|*|*|#|*|*|#|#|*|*|#|*|*|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome605() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|*|#|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|#|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome606() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | |#| | | |",
                        "|#| |#|*| | | |*| |#| | |*| | |#|",
                        "|#|*|#|#| | | |*| |#| | |#| |#|*|",
                        "|*|#|#|*|*| |*|*| |#| | |*| |*|*|",
                        "|#|#|#|*|*|#|#|*|*|*|#|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome607() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |*| |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome608() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | |#| | |",
                        "| | | |*|#| | |",
                        "| |*| |*|#| | |",
                        "|#|*|*|*|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome609() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | |*| | | |",
                        "| | | |#| | | |",
                        "| | |#|*| | | |",
                        "| | |*|*| | | |",
                        "|*|#|#|#| | | |",
                        "|#|#|*|#|#| |#|",
                        "|#|#|*|#|*|*|*|",
                        "|*|*|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome612() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |#| |",
                        "| | | | | | | |*| |",
                        "| | | | | | | |#| |",
                        "|*| | |*|*| |*|*| |",
                        "|*| |*|#|#| |#|#|#|",
                        "|*|*|*|*|#|#|*|#|#|",
                        "|*|#|*|*|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome613() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|*| | | | | | | | | |",
                        "|*| | |#| | | | | |*|",
                        "|#|#| |#|*|#|*|#| |*|",
                        "|*|#|#|*|#|*|#|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome614() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | |#| | |*|",
                        "| | | | |#| | |*|",
                        "|#| | | |*| | |*|",
                        "|*| | | |*| | |#|",
                        "|*|*| |#|#| | |#|",
                        "|*|#|#|#|*|*|#|#|",
                        "|*|*|#|*|#|#|*|*|",
                        "|#|*|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome615() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*|#| | | | | | | |",
                        "|*|#| | | | | | | |",
                        "|*|#| | |*| | | | |",
                        "|#|#| | |*| | | | |",
                        "|*|#| |#|*| | | | |",
                        "|*|*|#|#|#|*|#| | |",
                        "|*|#|#|*|#|#|*| | |",
                        "|#|*|#|#|*|*|*|*| |",
                        "|#|#|#|*|*|#|#|#|#|",
                        "|*|*|#|#|*|*|*|*|#|",
                        "|*|#|*|#|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome616() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|*|#|*|*|#|*|*|#|*|",
                        "|*|#|*|#|*|*|#|#|#|#|#|",
                        "|#|#|#|#|#|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome617() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | |",
                        "| | | | | | |*| | | | | |",
                        "| | | | | | |#| | | | | |",
                        "| | | | | | |#| | | | | |",
                        "| | | |#| | |#| | | |#| |",
                        "| | |*|*| | |*| | | |*| |",
                        "| | |*|#| | |#|#|*| |*| |",
                        "| |*|#|#| |*|*|#|*| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome619() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | |*| | | |#|",
                        "| | | | | | |*| | | |*|",
                        "| | | | | | |*| | | |*|",
                        "|*| | |*|#| |#| | | |#|",
                        "|#| | |*|*| |#|#| |#|*|",
                        "|#| | |*|*| |#|*|*|#|#|",
                        "|*|#| |#|*| |#|#|#|#|#|",
                        "|#|*| |*|#|*|*|#|#|*|*|",
                        "|#|#|*|#|*|*|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome620() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "| | | | | | |*| | | | | | |",
                        "| | | | | |#|*| | | | |*| |",
                        "| |*|*| | |*|*| |*|#| |#| |",
                        "| |*|#| | |*|*| |#|#| |#| |",
                        "| |#|*|*| |*|*|*|*|#| |#|#|",
                        "|#|#|#|#|*|#|*|#|*|*| |#|#|",
                        "|#|*|*|#|#|#|#|*|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome621() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|*|*|#|#|*|*|#|*|#|#|*|",
                        "|*|#|#|#|*|#|*|#|*|*|*|*|*|#|",
                        "|#|#|#|#|*|*|#|#|#|*|*|*|*|*|",
                        "|*|*|#|#|*|#|*|#|*|#|*|*|*|#|",
                        "|#|*|*|*|#|#|#|*|#|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome622() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome623() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|#|*|#|#|#|#|#|*|*|*|",
                        "|*|#|*|#|#|*|*|*|*|*|#|*|*|",
                        "|#|*|*|#|*|#|#|*|#|*|*|#|#|",
                        "|*|#|*|#|*|#|*|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome624() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | |#| | | | |",
                        "| | | | | | | | |#| | | | |",
                        "| | | | | | | | |#| | | | |",
                        "| | | | | | |*| |#| | | | |",
                        "| | | | | | |*| |*|#|#| | |",
                        "| | |#| | | |*| |#|*|*| | |",
                        "|*| |#| | |*|*|*|*|*|#|*| |",
                        "|#| |*|#|*|#|*|*|*|#|*|#|*|",
                        "|*|#|*|#|#|*|*|*|#|#|#|*|#|",
                        "|#|#|*|#|#|#|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome625() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|#|#|*|#|*|#|#|*|#|*|#|",
                        "|*|#|*|#|#|#|*|*|#|*|*|#|#|*|",
                        "|*|#|*|#|#|*|*|*|*|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome626() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | |",
                        "| | | |#| | | |*| | | | |",
                        "| |*| |*| |*| |#| | | | |",
                        "|#|#| |*| |*| |#| |#| |#|",
                        "|#|*|#|#| |#|*|*| |*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome627() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | |",
                        "| | | | | | | | |#| | | | |",
                        "| | | |*| | | | |#| | | | |",
                        "| | | |*| | | | |*| | | | |",
                        "| |*| |*| |#|#| |#| |*| | |",
                        "| |#|*|*| |*|#|#|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome628() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| |*| | | | | | | | | | | | | |",
                        "| |*| | | | | | | |#| | | | | |",
                        "| |#| | | | | | | |#| | |#| | |",
                        "|*|*| | | |#|*|*| |#|#|#|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome629() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | | | | |",
                        "|*| | | | | | |*|#| | | | | |#| |",
                        "|#|*|*| |#| | |*|*|#| |#|#| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome630() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | |#|*| | | | | | | | | |",
                        "| | |*|#|*| | |#|#| | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome631() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | | | | |",
                        "| |*| | | |*|#| | |#| | |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome632() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| | | | | | |",
                        "| | |#| | | | | | | |#| |*|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome633() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome634() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome635() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#| | | | |#|",
                        "| | | | | | | |#| | | |#| | | | |#|",
                        "|*|*| | |*|#| |*| |#| |*|#| | | |#|",
                        "|*|*| |*|#|#| |*|*|#| |#|*|*| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome639() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |#|",
                        "| | | |#|",
                        "|*|*| |#|",
                        "|*|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome640() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| |*|#| |",
                        "|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome641() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | |#| |",
                        "| | |*|*|",
                        "|*|#|#|#|",
                        "|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome642() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome643() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|*|#|#|",
                        "|#|*|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome644() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | |#|*| |",
                        "| | | |#|#| |",
                        "| | | |*|*| |",
                        "| |#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome645() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | |#| |",
                        "| | | | |#|*|",
                        "| | | | |#|#|",
                        "|*|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome646() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | |#| | |",
                        "| | |*| | |",
                        "| | |#| | |",
                        "| | |#| | |",
                        "|*| |#| |*|",
                        "|#|*|*|*|*|",
                        "|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome647() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | |#| | |",
                        "| | |*| |#|",
                        "| | |*|#|*|",
                        "| |#|#|*|*|",
                        "|*|*|*|*|#|",
                        "|*|#|*|#|#|",
                        "|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome648() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |#| |",
                        "| | | | | | |#| |",
                        "| | | | | | |*| |",
                        "| | |*| | | |*| |",
                        "| | |*| | | |*| |",
                        "| | |#| |*| |#|#|",
                        "|#| |*| |*|#|*|*|",
                        "|*| |#|#|#|#|#|*|",
                        "|#|#|#|*|#|#|*|*|",
                        "|*|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome649() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome650() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |#| | | |",
                        "| | | |#|#| | |",
                        "|#| | |*|*|*|*|",
                        "|*|*| |#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome651() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | |#| | |*| | |",
                        "| | |*| | |#|#| |",
                        "| | |*| | |#|#| |",
                        "| |*|*|*|#|*|#|#|",
                        "| |*|#|*|*|*|#|*|",
                        "|*|#|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome652() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | |",
                        "|*| | | |#| | |*| | |",
                        "|*| | | |#| | |*| | |",
                        "|#| |*| |*| | |*| | |",
                        "|#|#|*| |#| | |#|#| |",
                        "|*|#|*| |*| | |*|*| |",
                        "|#|*|#|#|*| |#|#|*| |",
                        "|#|#|*|*|#|#|#|#|#|#|",
                        "|#|#|*|*|*|*|#|#|*|#|",
                        "|*|*|#|*|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome653() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "|#|*| | |*|#| | | | | |",
                        "|#|#| | |*|#| | | | | |",
                        "|*|*|*|*|*|*| |#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome654() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | |#| | | | | | |",
                        "| |#|*| |#|*|*| | |",
                        "| |*|*| |*|*|*|#| |",
                        "| |#|#|#|#|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome655() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | |*| |",
                        "| | | | | | | |*|*|*|",
                        "| |#|#| | | | |#|*|*|",
                        "| |#|#|#|#| |*|#|*|#|",
                        "|#|#|#|#|*| |*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome656() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | |*| | | |#| | | |",
                        "| |*|*|*|*| |#| |*|#|",
                        "|#|*|#|*|#| |#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome657() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | |#| | |*|#| | | |",
                        "| | |*| | |*|*| | | |",
                        "| | |#|*| |#|*| | | |",
                        "| | |*|#|#|#|*|#| |#|",
                        "| |#|#|#|*|#|*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome658() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | |*|*|*|",
                        "|*| | |#|#| |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome659() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | |*| |#| |",
                        "| | | | | |*| |#| |",
                        "| | | | | |*| |#| |",
                        "|*| | |*| |#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome660() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | |",
                        "| | | | | | | |#|*| |*| |",
                        "| | | | |*| |#|*|*| |#| |",
                        "| | |#| |#|#|#|*|*| |#| |",
                        "|*| |#|*|*|*|#|*|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome661() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | |#| | | | |",
                        "| |*| | | | | |*|#| |*| | |",
                        "| |*| | |*| | |*|#| |#| |#|",
                        "|#|#| | |*| | |#|#|*|*| |#|",
                        "|#|*|*| |#|*|*|*|#|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome662() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | |#| | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome663() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#|",
                        "| | | | | | | | | | | |#|",
                        "| |#| | | | | | | | | |*|",
                        "| |#| | | | | | | | | |*|",
                        "| |*|*| |#|*| | | | |*|#|",
                        "| |#|#| |*|*| |*| |*|#|*|",
                        "| |*|*|#|#|*|*|#| |*|#|#|",
                        "|*|*|#|*|*|#|#|#| |#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome664() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| |#| |*|*|#|#|#|*|#|#| |#|",
                        "|#| |*| |*|*|*|#|*|*|#|*| |#|",
                        "|#|#|#|#|*|*|*|*|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome665() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "|#|#|#|#|#|#|*|#|*|*|*|#| |#|*|",
                        "|*|*|#|#|*|*|#|*|*|*|#|#|*|*|#|",
                        "|#|*|*|#|*|#|#|#|#|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome666() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| |#| | |#| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome667() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | | |",
                        "| | |#|*| | | | |*| | | | | |",
                        "| | |*|*|#|*| | |#| | | | | |",
                        "|*|#|#|*|#|#| | |*|#|#| |#|#|",
                        "|*|*|#|*|#|#|#| |*|*|*|#|#|#|",
                        "|#|*|*|#|*|#|*|#|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome668() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |*| | | | | | | | | | | | | | | |",
                        "| |#| | | | |*|#| |#| | | | | | |*|",
                        "| |*| |*| | |*|*| |*| | | | | | |#|",
                        "|#|#|#|*|*|*|#|*|#|#|#|*|*|#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome669() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | | | | |",
                        "| | |*| | | | | | | | | | | | | | |",
                        "| | |*| |*| | | | | |#| | | | | |#|",
                        "| | |#| |*|*| | |*|#|#|#| |#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome670() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | | |*| | | | | | | | |",
                        "|#| | | | | |*|#| | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome671() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |#| | | | | |*| | | | | | | | |",
                        "| |*| | | |*| |*|#| | | |#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome672() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|*|#|*|*|#|",
                        "|*|#|#|#|#|*|",
                        "|#|*|#|*|#|#|",
                        "|*|#|#|#|*|#|",
                        "|#|*|*|*|#|*|",
                        "|*|*|#|*|*|#|",
                        "|#|#|*|#|#|*|",
                        "|#|*|#|#|*|*|",
                        "|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome673() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |*|",
                        "| | | | | | |*|",
                        "| |*| | | | |#|",
                        "| |#| | | | |#|",
                        "|#|#| |*| | |*|",
                        "|#|#|*|#| |#|#|",
                        "|*|#|*|*|*|*|#|",
                        "|#|*|#|*|*|*|#|",
                        "|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome674() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "|*|#| | | |",
                        "|#|*| | |*|",
                        "|*|#| |#|*|",
                        "|#|#| |#|*|",
                        "|*|*|#|#|*|",
                        "|#|*|*|*|#|",
                        "|#|#|*|#|#|",
                        "|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome675() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |#| | | | |",
                        "| |*| |*| | |",
                        "|*|#|*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome676() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|#| | | |#|#|#|#|",
                        "|*|#| | |#|*|*|#|",
                        "|#|*|*|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome677() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|#|*|#|#|*|*|",
                        "|*|#|*|*|*|*|*|*|#|",
                        "|#|#|*|*|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome678() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | |*|",
                        "| | | | | | |#|",
                        "| | |#| | | |#|",
                        "| | |*|*| | |#|",
                        "| | |*|#|#| |*|",
                        "| |*|#|*|#| |*|",
                        "| |*|#|#|*|#|#|",
                        "|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome679() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "|*| | | |*| | | |",
                        "|*| | | |*| | | |",
                        "|*|#| | |*| |#| |",
                        "|#|#|*| |*| |#| |",
                        "|#|*|*| |*|#|*| |",
                        "|#|#|#| |*|#|#|#|",
                        "|*|*|*|*|#|*|#|*|",
                        "|#|#|*|*|*|#|#|#|",
                        "|#|#|*|#|*|*|#|*|",
                        "|#|*|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome680() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "| | |#| | | |#|*| |#|#|",
                        "| |#|*| |#| |#|#|*|#|#|",
                        "|*|#|#| |#| |*|#|*|*|*|",
                        "|*|#|#|*|#|*|#|#|*|#|#|",
                        "|*|*|*|*|#|*|#|*|*|#|*|",
                        "|#|*|*|*|#|*|*|#|#|#|*|",
                        "|*|#|*|#|#|*|#|#|*|*|#|",
                        "|#|#|#|*|#|#|*|#|*|*|#|",
                        "|*|*|*|#|*|*|*|*|*|#|*|",
                        "|*|#|*|#|*|#|#|#|#|*|#|",
                        "|*|*|*|#|#|#|*|#|*|#|*|",
                        "|#|#|*|*|*|*|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome681() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |#|*| | | | |#| | | |",
                        "| |*|*| | | | |#| | | |",
                        "| |#|*| | | | |*| | | |",
                        "|#|#|#|*| | | |#| | | |",
                        "|#|*|#|#| | | |#| | | |",
                        "|*|*|*|#| |*|#|*| | |*|",
                        "|#|#|#|*| |*|#|*|*| |#|",
                        "|#|*|#|#| |*|#|*|*|#|#|",
                        "|*|#|*|#| |#|*|*|#|*|#|",
                        "|*|*|#|*|*|#|*|*|*|*|*|",
                        "|*|#|#|*|*|#|*|#|#|#|#|",
                        "|#|*|*|#|#|#|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome683() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |#| | | | | |#| | |",
                        "| |*| | |*| | |#| | |",
                        "| |#| | |#|*| |*|#| |",
                        "|*|#|*|*|*|#|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome684() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | |#| | | |#|*| | |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome685() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|#| | |*|#| | | | | | | | |",
                        "|*| |*|#|#| | | | | |#|#| |",
                        "|#| |#|*|*| | |*| | |#|*| |",
                        "|#|*|*|*|#|#|#|#| |*|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome686() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | |*| | |*|#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome687() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | |",
                        "| | | |#|*| | | |#| | | |",
                        "|#|*| |#|*| | | |#| | |*|",
                        "|#|#|*|#|#|*|#| |*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome688() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | |*| | |#| |#|*|#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome689() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|*| | | | | | | | |*| |#| |",
                        "|#|#| | | | | |*| |#| |#| |",
                        "|*|*| | | | | |*| |*| |*| |",
                        "|#|*| | |#| |*|*| |#|*|#| |",
                        "|#|#| | |#| |#|#| |*|*|#| |",
                        "|*|#| | |#|#|#|*|*|*|*|#|#|",
                        "|*|#| |*|#|#|*|*|*|*|#|#|*|",
                        "|*|#| |#|#|#|#|*|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome690() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |#| | | | | | | | |",
                        "| | |#| | | | | | | | |",
                        "| | |*| |*| | | | | | |",
                        "| | |#| |#| | | | | | |",
                        "| | |#| |*| | | | | | |",
                        "| |*|*| |#| | | |*|*| |",
                        "| |#|#| |*| |*| |#|#| |",
                        "|#|#|*| |#|#|#|*|#|*|*|",
                        "|*|#|#|*|*|*|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome691() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | |#| | |#| | |",
                        "|*|#| | |*| |#|*|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome692() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | |",
                        "|#|#|#| | |*| |*| |#| |*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome693() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |",
                        "|*|*| | | | | | |*| | | | | | |",
                        "|#|*| | | |#| |*|*|#|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome694() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| |",
                        "| | | | | | | | | |*|#| |#|*|",
                        "| | | |*| | |*|#|*|*|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome695() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |#| | |#| | | | |",
                        "|#| | |*| | |*| | |#| | | |#|",
                        "|*| |*|*|#| |*|*| |*| | |*|#|",
                        "|#| |#|*|*|*|#|*| |*|#| |#|#|",
                        "|*| |#|*|#|#|*|*|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome696() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "|*| | |#| | | | | | | | |*| | |#| |",
                        "|*|#| |#| |#| | |#| | | |#| | |*|*|",
                        "|#|#|*|#|*|#|*| |#|*|#|*|*| |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome697() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | |#|*| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome698() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|*|*|*|#|#|#|*|#|*|#|#|#|*|",
                        "|#|#|*|*|#|*|*|#|*|*|*|*|#|*|#|*|",
                        "|*|*|#|#|#|*|#|*|*|*|*|*|#|#|*|*|",
                        "|*|#|*|#|#|#|*|#|#|#|#|#|#|*|#|#|",
                        "|*|#|#|*|#|#|#|#|*|#|#|#|*|*|*|*|",
                        "|*|#|*|*|*|*|#|*|*|*|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome699() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | |#| | |#|*| | | | | |*| |",
                        "|*| | | |*| |*|#|#| |#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome700() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |*|",
                        "| |#| |*|",
                        "| |#| |*|",
                        "|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome701() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |*| |",
                        "| |*|*|*| |",
                        "|#|#|#|*|#|",
                        "|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome702() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|#| | |",
                        "|#| | |",
                        "|#| | |",
                        "|#| | |",
                        "|*|*| |",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome703() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| | | |",
                        "|*| | |*|",
                        "|#| | |#|",
                        "|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome704() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | |#| |#|*| | | |",
                        "| | |#| |*|#| | |*|",
                        "|#| |#|*|#|*| |#|*|",
                        "|*| |#|#|*|*|#|*|#|",
                        "|*| |*|*|#|#|#|#|#|",
                        "|#| |#|*|*|#|*|*|#|",
                        "|#|#|*|#|*|#|*|*|#|",
                        "|*|*|#|#|*|#|#|*|#|",
                        "|*|#|*|*|*|*|*|*|#|",
                        "|#|#|*|#|*|*|#|*|*|",
                        "|*|#|#|*|#|*|*|#|#|",
                        "|*|*|*|#|*|#|*|#|#|",
                        "|#|*|*|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome705() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|*|#|*|#|*|*|",
                        "|*|#|*|*|#|*|*|#|#|",
                        "|#|*|#|*|#|#|#|*|#|",
                        "|#|#|*|*|*|*|#|*|#|",
                        "|*|*|#|#|*|*|#|#|*|",
                        "|*|#|#|*|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome706() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome707() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | |#| | | | | |",
                        "| |*|*| |#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome708() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |*| | | | | |",
                        "| |*| | | |#| | | | | |",
                        "|#|#| |#| |#| |*|*|*|*|",
                        "|#|*|#|*| |#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome709() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome710() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | |#|",
                        "| | | | |#| | | | |#|",
                        "| | | | |*| | | |*|#|",
                        "|#|#|*| |#|*| | |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome712() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "| | | | | | |*| | | | | | |",
                        "| | | | |*| |#| |*| | | | |",
                        "| |#| |#|#| |#|*|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome713() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | | |",
                        "| | | | | |#| | |*| | | | | |",
                        "| | | | | |#| | |*| | | | |*|",
                        "| | | | | |#| | |#| | | |#|*|",
                        "| | | | | |#|#|#|*| | | |*|#|",
                        "|*| |*|*|*|#|*|*|*|*| |#|#|*|",
                        "|#| |#|#|*|*|*|#|*|*|#|#|*|#|",
                        "|#| |#|*|*|#|#|#|*|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome714() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | |",
                        "| | | | | |#| | |*|*| | |",
                        "| |*| | |#|*|*|#|#|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome715() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| | | | |#| |*| | |*| |",
                        "|#|#|#|#|#|*|*| |#|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome716() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |*| | | |#| | | |",
                        "|#| | |*| | | |#|*| | |*| | | |",
                        "|*| | |#| |#|#|#|#| | |*| | |*|",
                        "|#|*| |*|*|#|*|#|*| | |#| |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome717() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | | | | | |",
                        "| | |#| | | | | | |*| | | | | | |",
                        "| | |*| | | | | |*|#| | | | |#| |",
                        "| | |#| | |*| | |*|#| | | | |*|#|",
                        "|*|*|#| | |*| | |#|#| | |#| |#|*|",
                        "|#|#|*| | |#|*| |*|*|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome718() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |#|#| | | | | | | | | | |",
                        "| | |*|*| | | | | | | | |*| |",
                        "| | |#|*| | | | | | |*| |*| |",
                        "| | |*|#|*| | | |*| |*| |#| |",
                        "| | |*|#|#| |#|*|*| |#| |*| |",
                        "| |#|#|*|#|#|*|#|#| |*| |#| |",
                        "|#|#|*|*|#|*|#|*|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome719() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | |",
                        "| |#| | | | | | | | |*| | | | |",
                        "| |*| | | | | | | |#|#|*| |*|#|",
                        "| |#|#| | |#|#| | |#|#|*| |*|*|",
                        "|*|#|*|#| |*|*|#| |#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome720() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | | | |",
                        "| |#| |*| | |#| | | | | | | | |",
                        "| |*| |#| | |*| | |#| |*|#| | |",
                        "| |*| |#| | |*|*|#|*| |#|*| | |",
                        "|#|#| |*|*|*|*|#|*|#| |*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome721() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | | | |*| |",
                        "|*| |#| |#|*| |#|#| | |*| | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome722() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | | |",
                        "| | |*|#| | | | | | | | | | |",
                        "|#| |*|*| | |*| | |#| | | | |",
                        "|#| |*|*| | |*| |*|#| |#|*|#|",
                        "|*| |#|#| | |#|#|*|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome723() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| |#| | |#| | |",
                        "| |*|*|*| | | |*| |#| | |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome724() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | |#| | | | |#| | | | | | |*|",
                        "| |*|#| |#| |*| | |*| | | | | | |#|",
                        "|*|#|*|#|*|*|#|#|#|#| | | |*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome725() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|#|#|",
                        "|*|#|*|",
                        "|#|*|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome726() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | |*|*| | | | | |*|#| | |",
                        "|#| |#| | |#|#| | | | | |#|*|*| |",
                        "|#| |#|*|*|#|*| | |*| |*|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome727() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | | | | | | |",
                        "| | | |#|#| | | |#| |*| | | | | | |",
                        "| | | |*|*| | |#|#| |*| |#| |*|*| |",
                        "| |#| |#|#|*|*|#|*| |*| |#| |*|#|*|",
                        "|*|*| |#|#|#|*|#|*|*|#|*|*|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome728() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#| |",
                        "| | |#| |",
                        "|*| |#|*|",
                        "|*| |*|#|",
                        "|*| |#|*|",
                        "|*|#|*|#|",
                        "|#|*|*|#|",
                        "|*|#|#|*|",
                        "|#|*|#|#|",
                        "|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome729() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|#|*|*|*|#|",
                        "|#|*|*|#|#|",
                        "|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome730() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|#|#|#|",
                        "|#|#|*|",
                        "|*|*|*|",
                        "|*|*|*|",
                        "|#|#|*|",
                        "|*|#|*|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|#|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome731() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome732() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|#|#|#|#|",
                        "|*|*|#|*|#|*|*|",
                        "|#|*|*|*|#|#|#|",
                        "|#|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome733() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |#| | | | |",
                        "| |*|#| | | |#|",
                        "| |*|*| | | |*|",
                        "|*|*|#| | |#|#|",
                        "|#|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome734() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |*| |",
                        "| | | | |#| |",
                        "| | | | |#| |",
                        "|#| | | |*| |",
                        "|#| | | |*| |",
                        "|*| | | |#| |",
                        "|#|#| |*|#| |",
                        "|*|*|#|#|*| |",
                        "|#|*|*|*|#|*|",
                        "|*|#|#|#|*|*|",
                        "|#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome735() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "|#| |#|#|*| |",
                        "|*| |#|*|*| |",
                        "|#| |#|#|*|*|",
                        "|#|*|#|*|#|*|",
                        "|*|#|#|*|#|*|",
                        "|*|*|#|#|*|*|",
                        "|*|*|#|#|*|#|",
                        "|#|#|*|#|*|*|",
                        "|#|*|#|#|*|#|",
                        "|#|*|*|#|*|#|",
                        "|#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome736() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | |#| |*| |",
                        "| | |*|#|*|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome737() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| |#| | | | |*| | | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome738() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |#| | | | | |",
                        "|*| | | |#| | | | | |",
                        "|*|*| | |#|#|*| | | |",
                        "|#|*| | |*|#|*|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome739() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |#| |*|#|*| | | | |",
                        "| |*|*| |*|#|#| | | |*|",
                        "|#|*|*|*|*|#|#|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome740() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#| |*|",
                        "| | | | |#|*| |*|*| | |*| |#|",
                        "|#| | |*|*|#|#|*|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome741() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| |#|*| | |*| |#|#|#| |*|#|",
                        "|*|*|*|#| | |#|#|*|*|*|#|#|*|",
                        "|*|#|*|#|*|*|#|#|#|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome742() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | |#| |#| | | | | | |*| |",
                        "| | |*| |*| | | | | | |#| |",
                        "| | |*|#|*| | |*| |#| |#|*|",
                        "|#| |*|*|*| | |*|#|*| |#|*|",
                        "|#| |#|#|#|#|#|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome743() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | |",
                        "| | | | | | |*| | | | | | |",
                        "| | | | | | |#| | | | |#| |",
                        "| |*|*|#| | |#|#|#|#| |*|*|",
                        "| |*|#|*|*|#|#|*|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome744() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | |#| | | | | |*| | | | | | | |",
                        "| | |*| | |*|#|#|#| | | |*| | | |",
                        "| | |#|*| |*|#|#|#| |*| |#|#| | |",
                        "|*| |*|*|*|*|#|*|#|*|*| |#|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome745() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |*|#| | |*| | | | | | | |#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome746() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | |#| | | | | | | |",
                        "| |#| | |*| |*|*| | | | | | | |",
                        "| |*| | |#| |*|*|#|*|#|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome747() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|#|*|*|*|#|#|#|#|#|*|#|",
                        "|#|#|*|#|*|*|#|#|*|#|#|*|#|*|*|",
                        "|#|*|*|#|*|*|#|#|*|#|*|#|*|*|*|",
                        "|*|#|*|#|*|*|#|*|*|#|#|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome748() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | |#|",
                        "|*| |*|",
                        "|#| |#|",
                        "|#| |#|",
                        "|*|*|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome750() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|*|*|*|*|*|#|#|*|#|#|#|*|*|#|",
                        "|#|#|#|#|#|#|*|*|*|*|#|*|*|#|*|*|#|",
                        "|#|#|#|*|*|*|*|#|*|#|*|#|*|*|#|#|*|",
                        "|*|*|*|#|*|#|*|*|#|#|#|#|#|*|#|*|#|",
                        "|*|*|#|*|#|#|#|*|*|*|#|#|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome751() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|",
                        "|#|#|*|",
                        "|*|#|#|",
                        "|#|*|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|#|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome752() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|",
                        "|#|*|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome753() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|#|*|#|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|#|*|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome754() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | | | | | | |",
                        "| | | | | | |#| | | | | |#| | | | |",
                        "| | |*| |*|*|*| | | | | |#| | |*|#|",
                        "| |#|*|*|#|*|*|*|*|#|*|#|#| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome756() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| |*| | | |",
                        "| |#| | | |",
                        "| |*| | | |",
                        "|*|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome757() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | |#| |#|",
                        "|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome758() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#| |#|*|",
                        "|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome759() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | |#|*|",
                        "|#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome760() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|*| | | | | | |",
                        "|#| | | | | | |",
                        "|*| |#| |#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome761() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |#| | | | | | |",
                        "| |#|#| | |*| | |",
                        "| |#|*| | |*| |*|",
                        "| |*|*|#|*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome762() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |#|#| | | |",
                        "|*|#|*|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome763() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|#|*|#|#|#|*|",
                        "|*|#|#|*|#|#|#|",
                        "|*|*|*|#|*|#|*|",
                        "|*|#|#|#|#|*|*|",
                        "|*|*|*|*|#|#|*|",
                        "|*|*|#|*|*|*|*|",
                        "|*|#|#|*|#|#|*|",
                        "|#|#|*|#|*|#|*|",
                        "|*|*|#|#|*|#|#|",
                        "|*|#|*|*|#|*|*|",
                        "|*|*|#|*|*|#|#|",
                        "|*|*|#|#|#|#|#|",
                        "|#|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome764() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | |*| | | | | | |",
                        "| | |*| | | | | | |",
                        "| | |*| | | | | | |",
                        "|*| |*|#| | | |#| |",
                        "|*|*|*|#| |#| |#| |",
                        "|*|#|#|#| |*| |*|#|",
                        "|*|#|#|*|#|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome765() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| |*| | | | | | | | |",
                        "| |#| | | | | | | | |",
                        "| |#| | | | | | | | |",
                        "| |*| | | |#|*| | | |",
                        "| |#|#| | |*|*| | |#|",
                        "| |*|#| | |#|*| | |*|",
                        "| |*|*| |#|*|*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome766() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |#| |",
                        "| | | |#| | |*| |",
                        "| |*| |*| |*|*|#|",
                        "| |#| |*| |#|#|*|",
                        "|#|#|#|#| |*|*|*|",
                        "|*|#|#|*| |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome767() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | |",
                        "| |*| | | | | | | |",
                        "| |#| | | | | | | |",
                        "| |*| | | | | |*| |",
                        "|*|#| | | |#|#|*| |",
                        "|#|#| | | |*|*|*| |",
                        "|*|#|#|*| |#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome768() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| | |",
                        "| |#|*|*|*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome770() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |#| |*|*| |#|",
                        "|#|*|*|*|#| |#|",
                        "|#|*|#|#|*|#|#|",
                        "|#|#|*|*|*|*|#|",
                        "|#|#|*|#|*|*|*|",
                        "|*|#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome771() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| | |",
                        "| | | | | |#| | |",
                        "| | | | |*|*| |*|",
                        "|#|#|#|*|#|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome772() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |#| | | | | |",
                        "| | | | | |*| |*| | | |",
                        "|*|*| | | |#| |#|#| | |",
                        "|*|*|*| | |#| |*|*| |#|",
                        "|#|#|*| | |*| |#|#| |#|",
                        "|#|#|*| |#|*| |#|#|#|#|",
                        "|*|*|#|*|*|#|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome773() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | |#|",
                        "| | | | | | | | | |*|#|",
                        "|*| | | | | |*| | |#|#|",
                        "|#| | | | | |#| | |*|*|",
                        "|#|#|#|*| | |*|*| |*|*|",
                        "|*|#|#|*|#|*|#|*| |#|*|",
                        "|*|*|*|#|#|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome774() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | |#| | | | | |",
                        "| | |*|#| |#|#| | |",
                        "| | |*|*| |#|*| |*|",
                        "| | |*|*|*|*|*|#|*|",
                        "|#|#|#|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome776() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | |#|",
                        "| | | | | | | | | |*| | |*|",
                        "| |#| |#| | | | | |*| | |*|",
                        "|*|#|#|*| |#|#| |*|*| | |*|",
                        "|#|#|*|#|#|*|*|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome777() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | | |",
                        "| | | | |#| | | | | | | | |",
                        "| | | | |*|*| |*| | | | | |",
                        "| |#| | |#|#| |#| |#| |#| |",
                        "| |*|*|*|*|*|#|*|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome778() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | |",
                        "| | | |*| | | | | | | | |",
                        "| | |#|*| | | | | | | |#|",
                        "| | |#|#| | | | | | |#|#|",
                        "| |*|#|*| | | |*| | |*|*|",
                        "|*|#|#|*|#| |#|*| |#|*|*|",
                        "|#|*|#|*|#|#|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome779() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| |",
                        "| | | | | |*| | | |#|#| |",
                        "|#|#| |#| |#| | | |*|*| |",
                        "|*|#|#|*|*|#|*| |*|*|#|*|",
                        "|*|#|*|*|#|#|#| |*|*|*|*|",
                        "|#|*|*|#|*|#|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome780() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | | | |#| | | | |#| |#|",
                        "|*|#|*| | |#|*|*| | | | |*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome781() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome783() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | |#| | |#| | | |*| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome784() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | |#| | |*| | | |*| | | |",
                        "| | | |*|#| | |#| |#| |*| | | |",
                        "| | | |*|#| | |*| |#| |*| | | |",
                        "|*| |#|*|*| |#|#| |*| |#|*| |*|",
                        "|#| |#|#|*|*|#|#| |*| |*|#| |#|",
                        "|*|*|#|*|*|*|#|#|*|*|#|#|#| |#|",
                        "|#|#|#|*|#|#|*|*|#|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome785() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| | |",
                        "| | |#| | | | |#| | | | |*| | |",
                        "| |*|#| | |*| |*| | | | |#|#| |",
                        "|#|*|#|*| |#| |*| |*|*| |#|*| |",
                        "|*|*|#|*|#|#|#|*|*|*|#|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome786() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | |#|#| | | | |",
                        "| | | | | | | |#|#| | | | |",
                        "| | |*| | | | |#|*| | | | |",
                        "|*| |*| | | |#|#|*|*| |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome788() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | |#| | |",
                        "| |*|#| | | | |*| | | | | | |*| | |",
                        "| |*|#| | |#| |*|#| | | | | |#| | |",
                        "| |*|*| | |#| |*|*|*|#|*|*| |*| | |",
                        "|#|*|#|#| |#|#|#|#|#|*|*|#| |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome789() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| | | | | | | |*| | | |*| | | | |",
                        "|#|*|#|#| |*| | |#|#| | |*| | |*|*|",
                        "|*|#|*|*|#|#|*|*|#|#|#| |*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome791() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |#| | | |",
                        "| | | | | | | | | | | | |#| | | |",
                        "| |#| |#| | | | | | |#|#|*| | | |",
                        "|#|*| |*| | | | | | |*|*|#| |*| |",
                        "|#|*| |#| |*|*| |#|*|#|#|*| |#|#|",
                        "|#|#|*|*|*|#|#| |*|#|*|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome792() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|*|",
                        "|#|*|*|*|",
                        "|#|*|*|#|",
                        "|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome793() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | |#|",
                        "|#| | |#|",
                        "|*|*|*|*|",
                        "|#|*|*|#|",
                        "|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome794() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome795() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|#|*|",
                        "|*|*|*|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|#|*|*|",
                        "|#|#|#|",
                        "|#|*|*|",
                        "|*|*|#|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome796() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |*| | | | |",
                        "| |*| | | | |",
                        "|#|*|#| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome797() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|*|*|*|#|#|",
                        "|#|*|#|#|*|*|#|",
                        "|*|#|*|*|#|#|#|",
                        "|*|#|#|#|#|*|*|",
                        "|#|*|*|*|*|#|#|",
                        "|#|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome798() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*|*| | | |",
                        "|*|#| | | |",
                        "|#|#| | |*|",
                        "|#|#| |*|*|",
                        "|#|#| |*|*|",
                        "|*|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome799() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|#|#|*|#|",
                        "|#|#|*|#|#|*|",
                        "|*|#|#|*|#|*|",
                        "|*|*|*|*|*|*|",
                        "|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome800() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|#| | | | | | | | | | |",
                        "|#| | | | |*| |*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome801() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | |#| | | | | | |",
                        "| | | | |#| | | | | | |",
                        "|#| | |*|*| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome802() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | |#| |#|",
                        "| | | | | | | |*| |#|",
                        "| | |*| |*| | |*|#|*|",
                        "| | |#| |*| | |#|*|*|",
                        "| | |#| |*| | |#|#|*|",
                        "| | |*| |#| | |*|#|#|",
                        "| | |*|*|*|#|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome803() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |*| | | | | |",
                        "| | | | |*| | | |#|*|",
                        "| | | | |#| |*| |*|*|",
                        "| |*| |#|*| |*| |*|#|",
                        "| |#| |#|#|#|#| |*|#|",
                        "| |*|*|#|*|*|#| |#|*|",
                        "|*|#|*|*|#|#|#| |#|#|",
                        "|*|#|#|#|*|*|*|*|#|*|",
                        "|#|*|#|#|*|#|#|#|*|*|",
                        "|#|*|#|*|#|#|*|*|#|#|",
                        "|#|#|#|#|#|*|*|*|#|*|",
                        "|#|#|#|*|*|*|*|*|*|#|",
                        "|*|#|*|*|#|*|*|*|#|#|",
                        "|#|#|*|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome804() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| |*|*|*| |*| | | |*| | |#|",
                        "| |*|#|#| |*|*| |*|#|#| |*|",
                        "|#|*|*|#| |*|*| |#|#|*|#|*|",
                        "|*|#|*|#|#|#|#|*|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome805() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | |#| | | | |*|",
                        "| | | | | | |*| |*|#| | | |#|",
                        "|#|*|#|*|#|*|#| |#|#|*|#|#|*|",
                        "|*|#|*|*|#|*|#| |#|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome806() {
        check(GameOutcome.WIN_HASH, 6, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | |",
                        "| |*| | | | |*| | | | | |",
                        "| |*| | | | |#| | | | | |",
                        "| |*| |*| | |*| |*|#| | |",
                        "|*|*|*|*|#| |#| |#|*| | |",
                        "|*|*|#|#|#|#|#|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome807() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|*| |*|#| | | | | | | | | |",
                        "|#| |#|#| | |#|*|#| | | | |",
                        "|*| |*|#|*| |*|*|*| | |#| |",
                        "|*|*|#|*|*| |#|*|*| |#|#| |",
                        "|#|*|*|#|#| |*|#|#| |#|*|*|",
                        "|*|#|#|#|#|*|#|*|#|#|#|*|#|",
                        "|*|#|#|*|*|*|*|#|#|#|*|*|*|",
                        "|#|*|#|#|#|#|*|#|*|#|*|#|*|",
                        "|*|*|*|#|*|#|*|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome808() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |*| | |",
                        "| | | | | | | | | | | | |*| | |",
                        "| | | | | | | | | | | | |#| | |",
                        "| | | | | | | | |*| |#| |#|#| |",
                        "| | | | |*| | | |*| |*| |#|#| |",
                        "| | | |*|#| | | |*| |*| |#|*| |",
                        "| | |#|#|#| | | |#| |#|#|#|#| |",
                        "| | |*|#|*| | |#|*|*|#|*|*|*| |",
                        "|#|*|#|*|*|#|#|#|*|*|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome809() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "|#| | | |*| | | |#|#|#|*|*| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome810() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | | | |",
                        "| | | | | | | |#| |#| | |*| |",
                        "|*|*| |*| | | |#| |*| | |#|#|",
                        "|#|*| |*| |*|*|#| |#| |#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome811() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | |*| | | |*| |#| | | | | | |",
                        "| | |*| | | |#|*|*| | | |*| | |",
                        "|#|#|#|*|*| |*|#|#| | | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome814() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | | | | | |",
                        "| | | |*| | | |#| |#| | | | | | |",
                        "|#| | |*| | |#|*|#|*|#| | | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome815() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | |*|#| |#| | |*| | | | | |*| |",
                        "|#| |*|#|#| |#| | |#| |#|*| | |*| |",
                        "|*|*|#|#|*| |#| |*|*| |*|#|#| |*| |",
                        "|#|*|#|*|#| |#| |#|*|*|#|*|*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome816() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | |*| | | | | | |*| | |",
                        "| | | | | | | |*| | | |*|#|#|#| | |",
                        "|#|*| |#| |#| |#| |*| |*|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome817() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| |*|#|",
                        "|#|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|*|*|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome818() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |*| |*| | |*| | | |#| | | |*|#|",
                        "|#|#|#|#| | |*| | | |*|#| | |*|#|",
                        "|#|*|*|#| |#|#|*| |*|*|*| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome819() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | |*|#| |#| | | | | | | |#|",
                        "| | | | | |*|*| |*| |*| |#| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome820() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | |",
                        "|*| | | |",
                        "|*| | | |",
                        "|#| | | |",
                        "|*| | | |",
                        "|*| | | |",
                        "|#| |#| |",
                        "|#| |#| |",
                        "|*| |#| |",
                        "|#| |#| |",
                        "|*|*|#|*|",
                        "|*|*|#|*|",
                        "|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome821() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |*|",
                        "| | |#| |*|",
                        "| | |*| |*|",
                        "|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome822() {
        check(GameOutcome.TIE, 3, new String[]{
                        "|*|#|*|",
                        "|*|#|#|",
                        "|#|*|*|",
                        "|*|#|#|",
                        "|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome823() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*|*|*| |",
                        "|#|*|#|#|",
                        "|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome824() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| |#| | | | |*|",
                        "|#|*| | |*| |*|",
                        "|#|#| | |*| |*|",
                        "|*|#| | |#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome825() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |#| | | |",
                        "| | | |#| | | |",
                        "| | |#|*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome827() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | |*| |",
                        "| | | |#|#| |",
                        "| | | |*|*|#|",
                        "| | | |#|*|*|",
                        "|*| | |#|#|#|",
                        "|*| |#|#|#|*|",
                        "|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome828() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|#| | | | | | | | |",
                        "|*|*| | | | | | | |",
                        "|*|#| | |*|#|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome829() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | |*| |",
                        "| | | | | | | |*| |",
                        "| | |#| | | | |*| |",
                        "| | |#| | | | |#| |",
                        "|#| |#|*|#| | |*| |",
                        "|#|*|#|*|*| |*|#|*|",
                        "|*|*|#|*|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome830() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | |*| | | |#|"
                }
        );
    }

    @Test
    void calculateOutcome831() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | |#|#| |*| | |",
                        "|#|*|#|*| |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome832() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | |#| | |*| |*| | | | |",
                        "|*|#|#|*|#|#|*|#|*|*|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome833() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| |*| | | | | | | | | | | | |",
                        "| |*| |*|#| | | | | |#| | | |",
                        "| |*| |#|#| | | | | |#| | | |",
                        "| |#|*|#|#| | | |*|#|*| |*| |",
                        "|*|*|#|*|#|#|*|*|#|#|*|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome834() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome835() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| | | | | |#|#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome836() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#| | | | |",
                        "| | | | | | | | | | |*|#|#|*| | |",
                        "|#|*| | | | | | | | |*|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome837() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome838() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | |#| | | | | | | | | |",
                        "| |*| | | |*| | | | | | | | | |",
                        "| |#|*| | |#| | | | | | | | | |",
                        "|#|*|*|*|*|#| |*| |#| |#| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome839() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |*|",
                        "| | | | | | | | | | | | | | |*|",
                        "| |#|#| | | | | | | | | | |*|*|",
                        "|#|*|#|#| | |*|*|#|#| | | |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome840() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "|*| | |",
                        "|*| | |",
                        "|*| | |",
                        "|#| | |",
                        "|*| | |",
                        "|#| | |",
                        "|*|#|#|",
                        "|*|*|#|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome841() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "|*| |*|",
                        "|#| |#|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|#|#|*|",
                        "|*|#|#|",
                        "|*|*|*|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome842() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | |#| |#| |*| | |*| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome843() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | |*| | | | | | | | |",
                        "| | | | | | | | |#| | | | | | | | |",
                        "| | | | | | | | |#|*|*| | | | | | |",
                        "| | | |*| |#| | |*|*|#| | | |#| |*|",
                        "| | |*|*| |#| | |#|*|*| |*| |#| |*|",
                        "| |*|#|*| |#| |*|#|*|*| |#|#|*| |#|",
                        "|#|*|#|*|#|*|#|#|#|*|#|#|#|*|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome844() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|*|#|",
                        "|*|*|*|*|#|",
                        "|*|#|#|*|*|",
                        "|#|*|*|#|#|",
                        "|#|*|#|*|*|",
                        "|#|*|*|#|#|",
                        "|*|*|#|#|#|",
                        "|#|*|#|*|#|",
                        "|#|#|*|#|*|",
                        "|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome845() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|*|*|*|#|",
                        "|#|#|*|#|#|*|",
                        "|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome846() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|#|*|*|#|",
                        "|#|#|#|#|",
                        "|#|*|*|#|",
                        "|*|#|*|*|",
                        "|*|*|*|#|",
                        "|#|#|#|*|",
                        "|#|#|*|*|",
                        "|*|#|#|*|",
                        "|#|*|*|#|",
                        "|*|#|*|*|",
                        "|*|*|#|*|",
                        "|#|*|*|*|",
                        "|#|#|#|#|",
                        "|#|#|#|*|",
                        "|*|#|*|#|",
                        "|*|*|#|*|",
                        "|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome847() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|#|*|#|",
                        "|*|#|*|#|#|",
                        "|*|#|*|*|*|",
                        "|*|#|#|*|#|",
                        "|#|*|#|*|#|",
                        "|*|#|*|#|#|",
                        "|#|*|#|*|*|",
                        "|#|#|*|*|*|",
                        "|#|*|*|#|#|",
                        "|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome848() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | |#| | |",
                        "| |*|#| | |",
                        "| |*|#| | |",
                        "| |#|*|*|#|",
                        "| |*|#|*|*|",
                        "|#|#|#|*|#|",
                        "|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome849() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|*|#|*|",
                        "|*|#|#|*|*|",
                        "|*|#|#|#|#|",
                        "|#|#|#|#|*|",
                        "|*|#|*|*|#|",
                        "|*|*|#|*|*|",
                        "|#|*|*|*|#|",
                        "|#|*|#|*|#|",
                        "|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome852() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |#|#|*| |",
                        "|*| |#|*|#|#| |",
                        "|*| |*|#|*|#|*|",
                        "|*| |*|#|*|#|#|",
                        "|#|*|*|*|#|#|*|",
                        "|*|#|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome853() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | |#| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome854() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |#|",
                        "| | | | | |#|",
                        "| | | |#|#|*|",
                        "|*|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome855() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | | | | |",
                        "|#| |*| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome856() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|*|*|#|*|*|#|*|",
                        "|#|#|#|#|*|*|#|*|#|",
                        "|#|#|*|*|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome857() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*|#|#|*|#| |#|*|*|#|",
                        "|*|#|*|*|*| |#|#|*|*|",
                        "|#|#|#|*|*|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome858() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|#|#|#|*|*|",
                        "|*|*|*|*|#|*|#|*|",
                        "|#|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome859() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome860() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | |*| | | | | |",
                        "| | | | | |*| | | | | |",
                        "| | | | | |*| | | | |#|",
                        "| |#| | | |*| |*| | |*|",
                        "| |*| | | |*|#|*| | |#|",
                        "| |#| | | |#|*|#| | |*|",
                        "| |#| |*| |*|*|#|*| |#|",
                        "| |#|*|#| |#|*|*|#| |*|",
                        "| |#|#|*|#|#|*|#|#| |*|",
                        "| |#|#|*|#|*|*|*|#|*|#|",
                        "|#|*|#|*|#|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome861() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | |#| | | | | | | |",
                        "| | |*| |#| |#| | | | | |",
                        "|*| |#| |#| |*| | |*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome862() {
        check(GameOutcome.WIN_HASH, 7, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | |#| | | | |",
                        "| | | | | |*| | | | |",
                        "| | | | | |*|*| | | |",
                        "|#| | |*| |*|#|*|#| |",
                        "|#|#|#|#|#|#|#|*|*| |",
                        "|*|*|#|*|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome863() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | |#|*| | | | | | | |",
                        "| |#|#|*|*|#| | |*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome864() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |#|#| | | |*|*| | | |#|#|*| |",
                        "| | |#|#| | | |*|#| | | |*|#|#|#|",
                        "| | |*|*|*|*| |#|#| |#| |#|#|#|*|",
                        "|*| |*|#|*|#| |#|#|#|#|*|#|*|#|#|",
                        "|#| |*|*|#|#| |#|*|*|*|#|#|*|*|*|",
                        "|#| |*|*|*|*|#|*|*|*|*|*|*|#|*|*|",
                        "|#| |#|#|#|*|#|#|#|*|*|*|*|*|#|*|",
                        "|*|#|#|#|*|*|#|#|*|#|*|*|*|*|#|#|",
                        "|*|#|#|*|#|*|*|#|*|#|#|*|#|*|*|#|",
                        "|#|#|*|#|*|*|*|*|*|*|#|#|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome865() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| |#| | |*|*|*| | |*| | | | | | |#|",
                        "| |*| | |*|#|*| | |#| |#|#|*| |#|*|",
                        "|*|#| |#|*|*|#|*|#|#|#|*|#|*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome866() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | | |",
                        "|#|*| | | |*| | | |*| | | | | |",
                        "|#|#|*|#|*|#|*|#|#|*| |*| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome867() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | | | | |*|",
                        "|#| |*| |#|#|*| | |#| | | | | |#|",
                        "|*| |*|*|#|#|*|*| |#|#|#|*|*| |#|",
                        "|#| |#|#|*|*|*|#|*|*|#|#|#|*| |*|",
                        "|*|#|#|*|#|*|#|*|*|#|*|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome868() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|*|#|",
                        "|*|#|*|",
                        "|*|#|#|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome869() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|#|",
                        "|#|*|#|*|",
                        "|*|#|#|#|",
                        "|*|*|*|*|",
                        "|*|#|#|#|",
                        "|*|#|*|#|",
                        "|#|*|*|#|",
                        "|#|*|*|#|",
                        "|*|#|*|*|",
                        "|*|#|#|*|",
                        "|#|#|*|#|",
                        "|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome870() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|*|*|#|#|#|*|#|*|*|#|*|*|*|#|",
                        "|#|#|*|*|*|#|*|#|*|#|#|#|*|#|#|*|#|",
                        "|#|*|*|#|#|#|*|*|*|#|*|*|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome871() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | |",
                        "| | | |",
                        "| |#| |",
                        "| |*| |",
                        "| |#| |",
                        "| |#| |",
                        "| |*|*|",
                        "|#|#|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome872() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | | | |#|",
                        "|*|#|#| | |*|",
                        "|#|#|*|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome873() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|*|#|",
                        "|#|#|*|#|#|*|",
                        "|*|#|*|*|*|*|",
                        "|#|*|#|#|#|*|",
                        "|*|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome874() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|*|*|*|",
                        "|#|*|#|#|",
                        "|*|*|#|#|",
                        "|#|*|#|#|",
                        "|#|*|#|*|",
                        "|*|#|#|#|",
                        "|*|#|#|*|",
                        "|#|#|*|#|",
                        "|*|*|*|*|",
                        "|*|#|*|#|",
                        "|#|*|*|*|",
                        "|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome875() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|#|*|",
                        "|*|*|*|#|#|",
                        "|#|*|#|*|*|",
                        "|*|#|*|*|#|",
                        "|*|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome876() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "|#| | | | | | | |",
                        "|#| | |*|*| | |*|",
                        "|#|*|#|*|#| | |#|",
                        "|#|#|*|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome877() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| | |",
                        "|#| | | | |*| | |",
                        "|#| | | | |*| |#|",
                        "|#|*| |*| |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome879() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|*| |#| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome880() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |#|*| | | |"
                }
        );
    }

    @Test
    void calculateOutcome881() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | |*| | | | | |",
                        "| | |#|*| | | | |",
                        "|#| |*|#|*| |#| |",
                        "|#|#|*|*|#|*|*| |",
                        "|#|*|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome882() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | | | | |",
                        "|#| |*| | | |",
                        "|*|#|#| | | |",
                        "|#|#|*|#| | |",
                        "|*|*|#|*| |#|",
                        "|#|#|*|*|#|*|",
                        "|#|*|#|*|#|*|",
                        "|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome883() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|#|*|#|#|#|",
                        "|*|*|*|#|#|*|*|",
                        "|#|#|#|*|#|#|*|",
                        "|*|*|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome884() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | |*| | | | | | |",
                        "| | |#|*| |#| | | |#|",
                        "| | |#|*| |*|#|*| |*|",
                        "|*|#|*|#|#|*|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome885() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | |*| |*|",
                        "| | | | | |#|*|*| |#|",
                        "|#|*| | | |#|*|*| |#|",
                        "|#|*| |#|#|*|*|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome886() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "|#| |*| | | | | |",
                        "|*| |#|#| | |*| |",
                        "|#| |*|*| | |#| |"
                }
        );
    }

    @Test
    void calculateOutcome888() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | |#| | | | | |",
                        "|*| | |*| | |#| | | | |#|",
                        "|#| | |*| | |#| | | |*|*|",
                        "|*| | |*|#|*|*| | | |*|#|",
                        "|#| |#|#|#|*|#| |#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome889() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | |",
                        "| |*| |#| | | | | |#|*| |",
                        "|#|#|*|*|*|*|*| | |#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome890() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|*|*| | | | | | | | | |",
                        "|*|#| | | | | | | | | |",
                        "|#|*| |*| | | | | | | |",
                        "|#|*| |*| | |#| | | | |",
                        "|*|*| |#|#|*|#|#|*| |#|",
                        "|#|#|#|#|#|#|#|*|*| |#|",
                        "|#|*|#|*|*|#|*|*|*|*|#|",
                        "|*|*|#|*|*|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome891() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | |*| | | | |#| |",
                        "| |*| | |#| | |*| |#| |",
                        "|*|#|*|*|#| |*|#| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome892() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| |#| |*| | | |#| | | | | | |",
                        "| |*| |*|*| | |*|#| | | | | |",
                        "| |#|*|#|#|#|#|#|*| |#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome893() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | |",
                        "| |*| | | | | | |*| | |*| | |",
                        "|*|#| | |#| |*| |*|#| |#|*| |",
                        "|*|#| | |#|#|*| |#|*| |#|*| |",
                        "|*|#| |*|*|#|#|#|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome894() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | |*| | | | | | | | |#|",
                        "| | | |#|#| | | |#| | | |*|",
                        "| | | |#|#|*| |#|#| | |#|*|",
                        "|#|*|*|*|#|#|*|#|*|*|#|*|*|",
                        "|*|#|*|*|#|#|*|*|#|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome895() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "|#| | | | | | | | | | | |#|",
                        "|*| |#| | | | |#|*|*| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome896() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | |*| |#| | | |"
                }
        );
    }

    @Test
    void calculateOutcome897() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | |#| | | |*| | | | |",
                        "| |*| | |#| | | |#| | | | |",
                        "| |*| |#|#| |#|*|*| |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome898() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | |",
                        "|*|*| | | | |*|#| |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome899() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | |#| | | | | | | | | |",
                        "| | |*| | | | | | | | | |",
                        "|#| |*|*| | | |#| | | | |",
                        "|#| |*|*| | |*|*| | | | |",
                        "|*| |#|*| | |*|#|#| |#|#|",
                        "|#| |#|*|#|*|*|#|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome900() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#|#|#|*| |*| |*|#| | |*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome901() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | |#| | | | | | | | | | | | |",
                        "|#| | |*|*| | | | | | | | | | | |",
                        "|#| |#|*|#| | | | |*| | | | | |*|",
                        "|#| |#|*|#| | | |*|#| | |*| | |*|",
                        "|*|#|#|#|*| | | |*|*|#| |*|#|#|#|",
                        "|#|*|*|#|*| |#| |#|*|*|*|#|*|*|*|",
                        "|#|#|*|#|#|#|#|*|*|*|#|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome902() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | |*| | | | | | | | |#|",
                        "| | | | |*| | | | | | | | |#|",
                        "| | | | |*|#| | | | | | | |#|",
                        "| |*| | |*|*|*|#|#| | | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome903() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| |#| | | |#| | |#| | | | | | |",
                        "| |*| | |*|*|*| |*| | | |*|#|*|",
                        "|#|*| |#|*|*|#|#|#|#|#| |#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome904() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |#| | | | | | |",
                        "|*| | | | | | | | | |#| | | | | | |",
                        "|*| | | | | |*| | | |*| | | |*|#| |",
                        "|*| | | | | |#| | |#|#| | | |*|#| |",
                        "|*|#|*| | |#|#| | |#|#|#|*|*|#|*|#|",
                        "|*|#|#|*|*|*|*|#|#|#|*|#|*|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome905() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|*|#|",
                        "|*|*|#|",
                        "|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome906() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |*| | |",
                        "| | | | |*| | | |#| | |#|*|#| | |"
                }
        );
    }

    @Test
    void calculateOutcome907() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "|*| | | | | | | | | | | | | | | | |",
                        "|*| | | | | | | | |*| | | | | |#| |",
                        "|*|#| |*| | | | | |*| |#| | | |*|*|",
                        "|*|#| |*| |#|*| | |*| |#|*| | |#|#|",
                        "|*|*|#|#|#|*|#|#| |*|#|#|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome908() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|#|#|*|",
                        "|#|*|#|*|#|",
                        "|*|*|#|#|*|",
                        "|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome909() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "|*| |#|#| |",
                        "|#| |*|#| |",
                        "|*| |#|*| |",
                        "|#|*|*|#| |",
                        "|*|#|*|*|*|",
                        "|*|*|#|*|#|",
                        "|*|*|*|#|*|",
                        "|#|#|#|#|#|",
                        "|#|#|*|#|#|",
                        "|*|#|#|#|*|",
                        "|#|*|*|*|*|",
                        "|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome910() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | |#|",
                        "|#| |*|",
                        "|#|#|*|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome911() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| |#| | |",
                        "| |#| | |",
                        "| |#| | |",
                        "| |#| | |",
                        "| |#| | |",
                        "| |#|*|#|",
                        "| |*|#|*|",
                        "| |#|*|#|",
                        "| |#|*|*|",
                        "|*|#|*|*|",
                        "|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome912() {
        check(GameOutcome.TIE, 5, new String[]{
                        "|*|*|*|#|",
                        "|*|#|*|#|",
                        "|*|*|*|#|",
                        "|#|#|*|#|",
                        "|*|*|#|*|",
                        "|#|#|#|*|",
                        "|#|#|*|#|",
                        "|*|*|#|#|",
                        "|*|#|*|*|",
                        "|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome913() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|*| | | |#|",
                        "|#|*| | |#|",
                        "|#|*|*|*|*|",
                        "|*|#|*|#|#|",
                        "|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome914() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|*|",
                        "|#|#|#|",
                        "|*|*|*|",
                        "|*|#|#|",
                        "|#|#|*|",
                        "|#|*|*|",
                        "|#|*|*|",
                        "|#|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome915() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#|*| | |",
                        "|*|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome916() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|*|*|*|",
                        "|*|*|*|*|#|#|",
                        "|#|*|#|#|#|#|",
                        "|*|#|*|#|#|*|",
                        "|*|*|#|*|*|#|",
                        "|*|#|#|*|*|*|",
                        "|#|*|*|#|#|#|",
                        "|#|*|#|*|*|*|",
                        "|#|#|#|*|#|#|",
                        "|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome917() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|#|#|#|*|*|",
                        "|*|*|*|#|#|#|*|",
                        "|*|*|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome918() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|*|#|#|#|*|",
                        "|*|#|*|*|#|",
                        "|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome919() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | |*|#| |#|",
                        "|*| |*|#|*|#|",
                        "|*|*|#|#|*|#|",
                        "|*|#|*|*|#|#|",
                        "|*|*|#|*|*|#|",
                        "|#|#|*|#|#|*|",
                        "|#|#|*|#|#|*|",
                        "|*|*|*|*|*|#|",
                        "|#|#|*|*|#|#|",
                        "|*|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome920() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|#|#|#|#|*|*|#|",
                        "|*|#|*|#|*|*|#|*|*|",
                        "|#|*|#|*|#|#|#|#|*|",
                        "|#|*|#|*|*|*|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome921() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | |#| | |",
                        "| | | | | | |#| | |",
                        "| |*| | | |#|#| | |",
                        "|*|*| | | |#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome922() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| |*| | | | | |",
                        "| |#| | | | | |",
                        "|*|*| | | | | |",
                        "|*|#| | | | | |",
                        "|#|*| |#| | |#|",
                        "|#|*| |#| |*|*|",
                        "|#|*| |#| |*|#|",
                        "|#|#| |*| |#|#|",
                        "|#|#| |#|*|*|*|",
                        "|#|#|#|*|#|*|*|",
                        "|*|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome923() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|*|*|#|#|*|",
                        "|*|#|*|#|*|*|#|#|",
                        "|*|*|#|#|#|*|*|#|",
                        "|*|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome924() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | |*| | |",
                        "|*|#| | |#| | | |#| | |",
                        "|*|*| | |*|*| | |#| | |",
                        "|*|#|#| |#|#| |#|#| | |",
                        "|#|*|*| |*|*| |#|#| |*|",
                        "|*|*|*| |#|#|*|#|*|*|*|",
                        "|#|#|#|*|#|*|#|*|#|*|#|",
                        "|*|#|#|*|*|#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome925() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | |*| | | | | |",
                        "|#| | | | |#| | | | | |",
                        "|#| |*|*|#|*| |#| | | |",
                        "|#|*|#|*|*|#| |#| |*|*|"
                }
        );
    }

    @Test
    void calculateOutcome926() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|#| | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome927() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |*| | | | |#|",
                        "| | |#|*|#| |*|#| |*|",
                        "| | |*|#|*|*|*|#| |*|",
                        "| |*|*|#|#|#|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome928() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | |*| | |*| | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome929() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|*|*|*|#|*|#|*|#|#|#|*|#|#|#|#|",
                        "|#|#|*|#|*|*|*|#|*|#|*|*|#|#|#|#|",
                        "|#|*|*|#|#|*|*|#|*|*|#|*|*|*|*|*|",
                        "|#|*|#|#|#|#|*|*|*|*|*|*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome930() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| |*| | |#| | | | | | | | | |",
                        "| |#| |#|#| | | | | | | | |*|",
                        "| |*|*|*|#|*| | | | |*| |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome931() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | |#| | | | | |",
                        "|*| | | | | | | | |#| | | | | |",
                        "|#| | | | | | | | |*| | | | | |",
                        "|*| | | | | | | | |*| | | | | |",
                        "|*| | | | | | | | |#| |#|#| |#|",
                        "|#| |#| | | | | | |#| |*|#| |*|",
                        "|#| |#|*|*|*| | | |#| |*|*| |#|",
                        "|#|*|#|*|*|*|*|*|*|#|#|*|#| |#|",
                        "|*|*|#|#|*|*|*|*|#|*|#|#|#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome932() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| | | |",
                        "| |#| |",
                        "| |*| |",
                        "| |#| |",
                        "| |*| |",
                        "| |#| |",
                        "|*|#| |",
                        "|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome933() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|*|*|#|",
                        "|#|#|*|",
                        "|#|*|*|",
                        "|*|#|*|",
                        "|#|#|*|",
                        "|#|#|*|",
                        "|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome934() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| |#| | | | | | | | | | | | | | | |",
                        "| |#| |#| | | | | | | | | | | | | |",
                        "| |*| |#| | |#| |*| | | | | | | | |",
                        "| |#| |#| |*|#| |#|*| | |*|#|*|*| |",
                        "|*|#| |#|#|*|#| |#|*|*|*|#|*|*|*|#|",
                        "|*|#|#|*|*|#|#|#|*|*|*|#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome935() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|#|*|*|*|#|#|*|#|#|*|#|#|*|#|*|*|*|",
                        "|#|*|#|#|*|*|#|*|*|*|*|*|*|*|#|*|*|",
                        "|*|*|#|#|#|#|#|#|#|*|*|#|#|*|*|#|#|",
                        "|#|#|#|#|#|#|#|*|*|#|*|*|#|*|#|*|*|",
                        "|*|#|#|*|#|#|#|*|#|*|#|*|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome936() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | |*| |",
                        "|*| |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome937() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | |",
                        "|*| | | | |",
                        "|*| | | | |",
                        "|*| | | |#|",
                        "|*| |#| |#|",
                        "|#| |*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome938() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|#|#|",
                        "|*|*|*|*|",
                        "|*|#|#|*|",
                        "|#|*|#|#|",
                        "|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome939() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | |*| |",
                        "| | |*| |",
                        "| | |#|#|"
                }
        );
    }

    @Test
    void calculateOutcome940() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|#| |*|#| | | |",
                        "|#| |*|#| | |*|",
                        "|#| |#|*|#| |*|",
                        "|#|*|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome941() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | |*| | | |",
                        "| | |*| |#| |#| |",
                        "|*| |*| |#| |*|*|",
                        "|#|#|#|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome942() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "|*| | |*| | |",
                        "|*| | |#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome943() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | |#| | |",
                        "| | | | |#| | |",
                        "| |*| |*|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome944() {
        check(GameOutcome.WIN_STAR, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|#| | | | |*| |",
                        "|#| | |#| |*| |",
                        "|*|*|*|*|#|#| |"
                }
        );
    }

    @Test
    void calculateOutcome945() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | |*| | | | |"
                }
        );
    }

    @Test
    void calculateOutcome946() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | |*|",
                        "| |#| | |#|*|",
                        "|*|#| | |#|#|",
                        "|#|*| |*|*|*|",
                        "|*|#| |*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome947() {
        check(GameOutcome.TIE, 8, new String[]{
                        "|*|#|*|#|*|#|",
                        "|*|*|#|*|*|*|",
                        "|*|#|*|#|*|#|",
                        "|#|*|#|#|#|*|",
                        "|#|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome948() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| |#| | | | | | | |",
                        "| |#| | | | | | | |",
                        "| |#|*| | | | | | |",
                        "| |*|#| | | | | | |",
                        "|#|*|#|*| |*| |*|#|"
                }
        );
    }

    @Test
    void calculateOutcome949() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | |*| | | |",
                        "| | | | | |#| | | |",
                        "|#| | | | |*| | | |",
                        "|#| | | | |#| | | |",
                        "|#| | | | |#| | |#|",
                        "|#| | | | |*| | |*|",
                        "|*|#| | |*|*|*| |*|",
                        "|#|*|#|#|*|#|#|*|*|",
                        "|*|#|*|*|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome950() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | |",
                        "| | | |*| | | | |",
                        "| | | |#|*| | | |",
                        "| | | |*|#|#| | |",
                        "|#| | |*|*|*| |*|",
                        "|*|#| |*|#|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome951() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | |#| |*|",
                        "| |*| | |#|#| |#|",
                        "|#|*|#| |*|*|#|*|",
                        "|#|*|#| |#|*|*|*|",
                        "|*|#|#| |*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome952() {
        check(GameOutcome.WIN_HASH, 3, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | |*| |",
                        "| | |#|#|#| |#|*| |*| |"
                }
        );
    }

    @Test
    void calculateOutcome953() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | |*| | | | | | |",
                        "| |#|#|#|#|*| |*| | |#|*|"
                }
        );
    }

    @Test
    void calculateOutcome954() {
        check(GameOutcome.WIN_STAR, 4, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "|#| | | | | | | |*| |",
                        "|#|*| |*| | |#| |#| |",
                        "|#|#|#|*| |*|#| |*| |",
                        "|*|#|*|*|#|*|#| |*|*|",
                        "|#|#|#|*|*|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome955() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "|*| | | | | | | |#| |#|",
                        "|*|*| |#| |*|*|#|*| |#|"
                }
        );
    }

    @Test
    void calculateOutcome956() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | |#| | |",
                        "| | | | | | | | | | |#| | |",
                        "| | |*| | | | |*| | |#| | |",
                        "|*| |#| | |#|*|#|*| |*| | |",
                        "|*| |*| | |*|#|*|*|#|#| |#|",
                        "|#| |*| | |#|#|#|*|*|*|*|#|",
                        "|#| |#|#| |#|*|#|#|#|*|#|#|",
                        "|*| |#|*| |#|#|*|*|*|*|*|#|",
                        "|#|*|*|#|*|#|*|#|#|*|*|*|*|",
                        "|*|#|*|*|*|#|#|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome957() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | |#| | | |",
                        "| | | | | | | | | | |*| | | |",
                        "| | | | | | | | | | |*| | | |",
                        "|#| | |#| | | | | | |#|*| |*|",
                        "|*| | |#|*|#| | | | |*|#| |*|",
                        "|#| | |#|*|#| | |*|*|*|#|*|#|",
                        "|#|#| |*|*|*| | |#|*|#|#|*|*|",
                        "|*|#| |#|#|*| |*|*|#|*|*|#|*|",
                        "|*|#|#|#|*|#|*|#|*|*|#|#|#|#|",
                        "|#|#|#|*|*|#|*|*|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome958() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| |",
                        "| | | |*|#|*| | | | |*| |",
                        "| | |#|#|#|#|#|*| |*|#| |",
                        "|#| |*|*|*|#|#|#|#|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome959() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| |*| | | | | | | | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome960() {
        check(GameOutcome.IN_PROGRESS, 4, new String[]{
                        "| | |#|",
                        "| |#|#|",
                        "|*|*|#|",
                        "|*|*|*|",
                        "|#|*|#|",
                        "|*|#|#|",
                        "|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome961() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|*| | | |",
                        "|*| |#| |",
                        "|*| |#| |",
                        "|*| |*| |",
                        "|*|#|*| |",
                        "|#|#|*|#|",
                        "|#|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome962() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome964() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "|#| | | | |",
                        "|#| | | | |",
                        "|#| | |*| |",
                        "|#| | |*|#|",
                        "|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome965() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |",
                        "| | | | | | |"
                }
        );
    }

    @Test
    void calculateOutcome966() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "| | | | |",
                        "|#|#|*|*|",
                        "|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome967() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | |*|",
                        "| | | |#|*|",
                        "| | | |#|#|",
                        "|*| |#|#|*|",
                        "|*|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome968() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |#| |#|*|*| |*|"
                }
        );
    }

    @Test
    void calculateOutcome969() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|#|#|*|*|*|#|*|",
                        "|*|*|*|*|*|#|#|*|",
                        "|#|#|#|*|*|#|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome970() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | |",
                        "| | | | | | |",
                        "| |*| | | | |",
                        "| |#| | | | |",
                        "| |*| | | | |",
                        "|#|*|*| | | |",
                        "|*|#|#|#| | |",
                        "|#|*|#|*|*| |",
                        "|#|*|#|#|*| |"
                }
        );
    }

    @Test
    void calculateOutcome971() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|#| | | | | | |",
                        "|#| | | | | | |",
                        "|*| | |*| | | |",
                        "|#| | |*| |#| |",
                        "|#| | |*| |#|#|",
                        "|#|*|*|*|#|*|#|",
                        "|*|#|*|#|*|*|*|",
                        "|#|*|#|*|#|#|#|",
                        "|*|#|*|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome972() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|#|#|#|#|*|*|*|#|",
                        "|*|#|#|*|*|#|*|*|#|#|",
                        "|*|#|*|#|*|*|#|*|*|*|",
                        "|#|#|#|*|#|*|*|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome973() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | |*| | |",
                        "| |*|#| | | | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome974() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "|*| | | |*|#|*| | |",
                        "|*|*|#|#|#|*|#| | |",
                        "|*|#|#|#|*|*|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome975() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|#|#|*|*|#|*|#|#|#|",
                        "|*|*|#|#|*|#|*|#|*|",
                        "|*|#|*|*|#|#|*|#|#|",
                        "|*|#|*|#|#|*|#|*|#|",
                        "|*|*|#|#|#|*|*|#|#|",
                        "|#|*|*|*|#|*|*|*|*|",
                        "|*|#|#|*|*|#|*|*|#|",
                        "|*|*|*|*|#|#|#|#|#|",
                        "|*|#|#|*|*|#|*|#|*|",
                        "|#|#|*|*|#|#|#|#|*|",
                        "|*|*|#|#|*|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome976() {
        check(GameOutcome.WIN_HASH, 4, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| |#|*|*|#|#|#|#| |",
                        "| |*|*|#|#|#|*|*| |",
                        "|*|*|#|*|#|*|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome977() {
        check(GameOutcome.WIN_HASH, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | |#| | | | | |",
                        "| | | | |#| | | | |*|",
                        "| |#|*|#|#| | |#| |#|",
                        "|*|*|#|*|#|*| |*| |*|",
                        "|*|#|*|*|#|#|#|*|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome978() {
        check(GameOutcome.WIN_STAR, 5, new String[]{
                        "|#|#| |#|#|*|#|*|",
                        "|*|*|*|*|*|#|*|*|",
                        "|*|#|#|#|#|*|#|#|",
                        "|*|*|#|*|*|#|#|*|",
                        "|#|#|*|#|#|#|*|#|",
                        "|#|*|*|#|*|*|*|#|",
                        "|#|#|*|*|*|#|#|*|",
                        "|#|*|#|#|*|*|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome979() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "| | | | | | | | | |",
                        "|*| | | | | | | | |",
                        "|*|#| | | | | | | |",
                        "|#|#|*|#| | | | | |",
                        "|#|*|#|#|*|*| | | |",
                        "|#|*|#|*|*|#|*|*| |"
                }
        );
    }

    @Test
    void calculateOutcome980() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | | | | | | | | | |",
                        "| | | | |*| |*| | | | | |",
                        "|#| | |*|*| |#| | |*|#|*|",
                        "|#| |*|#|#|*|#| |#|#|#|*|",
                        "|*| |*|*|*|*|#| |#|#|*|#|",
                        "|*| |#|*|#|#|*| |*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome981() {
        check(GameOutcome.TIE, 7, new String[]{
                        "|*|#|#|#|#|*|*|#|#|#|*|*|",
                        "|*|#|#|*|*|#|*|#|*|*|*|#|",
                        "|#|*|#|*|#|#|#|*|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome982() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | | | | |",
                        "| | | | | | | |*| | |",
                        "| |*|#|#|#| | |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome983() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | | | |",
                        "| | | | | | | | | |*| |",
                        "| | | | | | | | | |*|#|",
                        "|*|#| | | | | |*| |#|#|",
                        "|*|*|*|*|#| | |#| |*|*|",
                        "|#|#|#|*|#| |#|#|*|#|#|",
                        "|*|#|*|*|#|*|*|#|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome984() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | |#| | | | | | | |",
                        "| | | | | | |*| | | |#| | | |",
                        "| | | | | |*|*|*| | |*|#| | |",
                        "| |#|*| |#|#|*|*|#|#|#|*|#| |"
                }
        );
    }

    @Test
    void calculateOutcome985() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | |#|*| |",
                        "| | | | | | | | | | | |*|*| |",
                        "| | |#|#| | | | |#| | |*|*| |",
                        "|*|*|#|*| |#| |#|*|*| |*|*| |",
                        "|*|#|#|*| |*| |*|#|*| |#|*| |",
                        "|#|#|#|*|#|#|#|#|*|#|#|*|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome986() {
        check(GameOutcome.IN_PROGRESS, 6, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | |#| | | | | | |*|",
                        "|#| |*| |*|#|#| |*| |#| |*|"
                }
        );
    }

    @Test
    void calculateOutcome987() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | |",
                        "| | | | | | | | | |*| | | |",
                        "| | | | | | | | | |*| | | |",
                        "|*| | | | |#| | | |*| |*| |",
                        "|*| | | | |#|*| | |#|#|*|#|",
                        "|#| | | | |#|#|#|*|*|#|#|*|",
                        "|#|#| |*|#|#|#|*|*|*|*|#|*|",
                        "|*|*|*|#|*|*|#|#|#|#|#|#|*|",
                        "|*|#|*|#|*|*|#|#|*|*|*|#|#|"
                }
        );
    }

    @Test
    void calculateOutcome988() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | |*| | | | | |",
                        "| | | | | | | | | | |*| | | | | |",
                        "| | | | | | | | | | |*| | | | | |",
                        "| | | | | | |#|#| | |#| | | | |#|",
                        "| | |#| |*| |*|*|#| |#| |*| | |#|",
                        "|#| |*| |#|#|*|#|#|*|*|*|#| | |*|"
                }
        );
    }

    @Test
    void calculateOutcome989() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | | |",
                        "| |#| | | | | | |*| | | | |#| | |",
                        "| |*| | |#| |*| |*| | | |#|*|*|#|",
                        "| |#|#| |*| |*|*|*|*| |#|#|#|#|*|",
                        "| |*|#|*|*|*|#|#|*|#|#|#|*|#|#|*|"
                }
        );
    }

    @Test
    void calculateOutcome990() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | |*| |#| | | |#| | |*| |"
                }
        );
    }

    @Test
    void calculateOutcome991() {
        check(GameOutcome.IN_PROGRESS, 3, new String[]{
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "| | | | | | | | | | | | | | | |",
                        "|#| | | | | | | | |*| | |*| | |",
                        "|#| | | | |*| |#|#|*| |#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome992() {
        check(GameOutcome.WIN_STAR, 6, new String[]{
                        "|#|#| |#| |#|",
                        "|#|#|*|*|*|#|",
                        "|*|*|*|*|#|#|",
                        "|#|*|*|#|*|#|",
                        "|#|#|*|*|*|#|",
                        "|#|*|*|#|*|*|",
                        "|#|*|*|*|#|#|",
                        "|*|#|#|#|*|*|",
                        "|*|#|*|#|#|*|",
                        "|*|#|#|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome993() {
        check(GameOutcome.TIE, 6, new String[]{
                        "|#|*|*|#|*|#|",
                        "|#|#|#|*|*|*|",
                        "|#|#|*|#|*|*|"
                }
        );
    }

    @Test
    void calculateOutcome994() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | |",
                        "| |*| | | |",
                        "| |#| |*| |",
                        "| |*| |*|#|",
                        "|#|*| |#|#|",
                        "|*|*| |#|#|",
                        "|#|#| |*|*|",
                        "|#|*| |#|#|",
                        "|#|*|*|#|*|",
                        "|#|#|*|*|#|",
                        "|*|#|#|*|*|",
                        "|#|#|#|*|#|",
                        "|*|#|*|*|#|",
                        "|*|*|*|*|#|",
                        "|*|*|#|*|*|",
                        "|*|#|*|#|#|",
                        "|#|#|#|*|#|"
                }
        );
    }

    @Test
    void calculateOutcome995() {
        check(GameOutcome.IN_PROGRESS, 5, new String[]{
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | | | | |",
                        "| | |#| | |"
                }
        );
    }

    @Test
    void calculateOutcome996() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| |*| |#| |#| | |",
                        "|#|#| |*| |*| | |"
                }
        );
    }

    @Test
    void calculateOutcome997() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | | | |",
                        "| | | | | | |*| |",
                        "| | |#| | | |#| |",
                        "| |*|*| |#| |#| |"
                }
        );
    }

    @Test
    void calculateOutcome998() {
        check(GameOutcome.IN_PROGRESS, 7, new String[]{
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "| | | | | | | |",
                        "|*| |*| | | | |",
                        "|*| |*|#|#| |#|"
                }
        );
    }

    @Test
    void calculateOutcome999() {
        check(GameOutcome.IN_PROGRESS, 8, new String[]{
                        "| | | | | | | |",
                        "| | | | | | |#|",
                        "| | | |*| | |#|",
                        "|*|*| |#| | |#|"
                }
        );
    }

    // -----------------------------------------------------------------------------------------------------------------

    static void check(GameOutcome expectedOutcome, int connectToWin, String[] board) {
        int columns = board[0].length() / 2;
        int rows = board.length;
        assertEquals(
                expectedOutcome,
                GameOutcomeSolver.calculateOutcome(
                        new ReadOnlyGameBoard() {
                            @Override
                            public int getNumColumns() {
                                return columns;
                            }

                            @Override
                            public int getNumRows() {
                                return rows;
                            }

                            @Override
                            public PlayerId getField(int column, int row) {
                                try {
                                    return playerIdFromChar(board[rows - row - 1].charAt(1 + 2 * column));
                                } catch (IndexOutOfBoundsException e) {
                                    throw new IndexOutOfBoundsException("Ungültiger Aufruf getField(" + column + ", " + row + ") bei Größe (" + columns + ", " + rows + ")!");
                                }
                            }
                        },
                        connectToWin
                ),
                "Falsches Ergebnis für connectToWin = " + connectToWin + "\n" + String.join("\n", board)
        );
    }

    private static PlayerId playerIdFromChar(char c) {
        return Arrays.stream(PlayerId.values()).filter(p -> PlayerId.toChar(p) == c).findFirst().orElse(null);
    }
}
